@@ -17,10 +17,11 @@ OC.L10N.register(
     "Processing files …" : "Zpracovávání souborů…",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Soubor {filename} nelze nahrát, protože je to buď adresář nebo má velikost nula bajtů",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedostatek místa pro uložení – velikost souboru je {size1}, ale zbývá pouze {size2}",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedostatek volného místa pro uložení – velikost nahrávaných dat je {size1}, volné kapacity úložiště ale zbývá už jen {size2}",
     "Target folder \"{dir}\" does not exist any more" : "Cílová složka „{dir}“ už neexistuje",
     "Not enough free space" : "Nedostatek volného prostoru",
     "An unknown error has occurred" : "Vyskytla se neznámá chyba",
+    "File could not be uploaded" : "Soubor se nepodařilo nahrát",
     "Uploading …" : "Nahrávání…",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Nahrání této položky není podporováno",
@@ -39,7 +40,12 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "Nepodařilo se načíst informace pro soubor „{file}“",
     "Files" : "Soubory",
     "Details" : "Podrobnosti",
-    "Select" : "Vybrat",
+    "Show list view" : "Zobrazit v seznamu",
+    "Show grid view" : "Zobrazit v mřížce",
+    "Please select tag(s) to add to the selection" : "Vyberte štítky které přidat do výběru",
+    "Apply tag(s) to selection" : "Uplatnit štítky na výběr",
+    "Select directory \"{dirName}\"" : "Vybrat složku „{dirName}“",
+    "Select file \"{fileName}\"" : "Vybrat soubor „{fileName}“",
     "Pending" : "Nevyřízené",
     "Unable to determine date" : "Nelze určit datum",
     "This operation is forbidden" : "Tato operace je zakázána",
@@ -59,7 +65,7 @@ OC.L10N.register(
     "Could not create file \"{file}\" because it already exists" : "Soubor „{file}“ nelze vytvořit, protože zde už existuje",
     "Could not create folder \"{dir}\" because it already exists" : "Složku „{dir}“ nelze vytvořit, protože už existuje",
     "Could not fetch file details \"{file}\"" : "Nedaří se získat podrobnosti o souboru „{file}“",
-    "Error deleting file \"{fileName}\"." : "Chyba mazání souboru „{fileName}“.",
+    "Error deleting file \"{fileName}\"." : "Chyba při mazání souboru „{fileName}“.",
     "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky hledání v ostatních složkách pro {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Pokud chcete hledat v ostatních složkách, zadejte více než dva znaky",
     "Name" : "Název",
@@ -69,9 +75,9 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů","%n soubory"],
     "{dirs} and {files}" : "{dirs} a {files}",
     "_including %n hidden_::_including %n hidden_" : ["včetně %n skrytého","včetně %n skrytých","včetně %n skrytých","včetně %n skrytých"],
-    "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo vytvářet soubory",
+    "You do not have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo zde vytvářet soubory",
     "_Uploading %n file_::_Uploading %n files_" : ["Nahrává se %n soubor","Nahrávají se %n soubory","Nahrává se %n souborů","Nahrávají se %n soubory"],
-    "New" : "Nový",
+    "New file/folder menu" : "Nabídka souboru/složky",
     "Select file range" : "Vybrat rozsah souborů",
     "{used} of {quota} used" : "Využito {used} z {quota} ",
     "{used} used" : "{used} využito",
@@ -79,15 +85,15 @@ OC.L10N.register(
     "File name cannot be empty." : "Je třeba vyplnit název souboru.",
     "\"/\" is not allowed inside a file name." : "„/“ není povolený znak v názvu souboru.",
     "\"{name}\" is not an allowed filetype" : "„{name}“ není povolený typ souboru",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné – nelze aktualizovat ani synchronizovat soubory!",
-    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "Skupinová složka „{mountPoint}“ je plná, soubory už nadále není možné aktualizovat nebo synchronizovat!",
-    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "Externí úložiště „{mountPoint}“ je plné, soubory už nadále není možné aktualizovat nebo synchronizovat!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložiště je plné – nelze aktualizovat ani synchronizovat soubory!.",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné – nelze aktualizovat ani synchronizovat soubory!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Skupinová složka „{mountPoint}“ je plná, soubory už nadále není možné aktualizovat nebo synchronizovat!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externí úložiště „{mountPoint}“ je plné, soubory už nadále není možné aktualizovat nebo synchronizovat!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Vaše úložiště je plné – nelze aktualizovat ani synchronizovat soubory!",
     "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Úložiště {owner} je téměř plné ({usedSpacePercent}%).",
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinová složka „{mountPoint}“ je téměř plná ({usedSpacePercent}%).",
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externí úložiště „{mountPoint}“ je téměř plné ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Vaše úložiště je téměř plné ({usedSpacePercent}%).",
-    "_matches '{filter}'_::_match '{filter}'_" : ["odpovídá „{filter}“","odpovídají „{filter}“","odpovídá „{filter}“","odpovídají „{filter}“"],
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["shoduje se s „{filter}“","shodují se s „{filter}“","shoduje se s „{filter}“","shodují se s „{filter}“"],
     "View in folder" : "Zobrazit ve složce",
     "Copied!" : "Zkopírováno!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Zkopírovat přímý odkaz (funguje pouze pro uživatele, kteří mají přístup k tomuto souboru/složce)",
@@ -112,9 +118,9 @@ OC.L10N.register(
     "Changed by {user}" : "Změnil(a) {user}",
     "Deleted by {user}" : "Odstranil(a) {user}",
     "Restored by {user}" : "Obnovil(a) {user}",
-    "Renamed by {user}" : "Přejmenoval(a) {user}",
-    "Moved by {user}" : "Přesunul(a) {user}",
-    "\"remote user\"" : "„uživatel na protějšku“",
+    "Renamed by {user}" : "Přejmenováno uživatelem {user}",
+    "Moved by {user}" : "Přesunuto uživatelem {user}",
+    "\"remote user\"" : "„federovaný uživatel“",
     "You created {file}" : "Vytvořili jste {file}",
     "You created an encrypted file in {file}" : "Vytvořili jste šifrovaný soubor v {file}",
     "{user} created {file}" : "{user} vytvořil(a) {file}",
@@ -130,12 +136,18 @@ OC.L10N.register(
     "{user} deleted an encrypted file in {file}" : "{user} smazal(a) šifrovaný soubor v {file}",
     "You restored {file}" : "Obnovili jste {file}",
     "{user} restored {file}" : "{user} obnovil(a) {file}",
+    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Přejmenovali jste {oldfile} (hidden) na {newfile} (hidden)",
+    "You renamed {oldfile} (hidden) to {newfile}" : "Přejmenovali jste {oldfile} (hidden) na {newfile}",
+    "You renamed {oldfile} to {newfile} (hidden)" : "Přejmenovali jste {oldfile} na {newfile} (hidden)",
     "You renamed {oldfile} to {newfile}" : "Přejmenovali jste {oldfile} na {newfile}",
+    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} přejmenoval(a) {oldfile} (skrytý) na {newfile} (skrytý)",
+    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} přejmenoval(a) {oldfile} (skrytý) na {newfile}",
+    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} přejmenoval(a) {oldfile} na {newfile} (skrytý)",
     "{user} renamed {oldfile} to {newfile}" : "{user} přejmenoval(a) {oldfile} na {newfile}",
-    "You moved {oldfile} to {newfile}" : "{oldfile} jste přesunuli do {newfile}",
+    "You moved {oldfile} to {newfile}" : "Přesunuli jste {oldfile} do {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} přesunul(a) {oldfile} do {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Soubor byl přidán, nebo odstraněn z vašich <strong>oblíbených</strong>",
-    "A file or folder has been <strong>changed</strong>" : "Soubor nebo adresář byl <strong>změněn</strong>",
+    "A file or folder has been <strong>changed</strong>" : "Soubor nebo složka byla <strong>změněna</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Oblíbený soubor nebo složka byla <strong>změněna</strong>",
     "All files" : "Všechny soubory",
     "Unlimited" : "Neomezeně",
@@ -143,7 +155,7 @@ OC.L10N.register(
     "Accept" : "Přijmout",
     "Reject" : "Odmítnout",
     "Incoming ownership transfer from {user}" : "Příchozí převedení vlastnictví od {user}",
-    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete přijmout {path}?\n\nPozn.: Proces po přijetí může trvat až hodinu.",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete přijmout {path}?\n\nPozn.: Proces převedení může trvat až hodinu po přijmutí.",
     "Ownership transfer failed" : "Převedení vlastnictví se nezdařilo",
     "Your ownership transfer of {path} to {user} failed." : "Převedení vlastnictví {path} od vás na {user} se nezdařilo.",
     "The ownership transfer of {path} from {user} failed." : "Převedení vlastnictví {path} od {user} se nezdařilo.",
@@ -158,31 +170,43 @@ OC.L10N.register(
     "New owner" : "Nový vlastník",
     "Search users" : "Hledat uživatele",
     "Choose a file or folder to transfer" : "Zvolte soubor nebo složku k převedení",
-    "Transfer" : "Převedení",
+    "Transfer" : "Převést",
     "Transfer {path} to {userid}" : "Převést {path} na {userid}",
     "Invalid path selected" : "Vybrán neplatný popis umístění",
     "Ownership transfer request sent" : "Žádost o převedení vlastnictví zaslána",
-    "Cannot transfer ownership of a file or folder you don't own" : "Není možné převést vlastnictví souboru či složky, které nejste vlastníky",
+    "Cannot transfer ownership of a file or folder you do not own" : "Není možné převést vlastnictví souboru či složky, kterých nejste vlastníky",
     "Tags" : "Značky",
     "Unable to change the favourite state of the file" : "Nedaří se změnit stav „oblíbené“ souboru",
     "Error while loading the file data" : "Chyba při načítání dat souboru",
+    "Pick a template for {name}" : "Vyberte si šablonu pro {name}",
+    "Cancel" : "Storno",
+    "Create" : "Vytvořit",
+    "Create a new file with the selected template" : "Vytvořit nový soubor ze zvolené šablony",
+    "Creating file" : "Vytváření souboru",
+    "Blank" : "Prázdný",
+    "Unable to create new file from template" : "Nedaří se vytvořit soubor ze šablony",
+    "Set up templates folder" : "Vytvořit složku pro šablony",
+    "Templates" : "Šablony",
+    "Unable to initialize the templates directory" : "Nepodařilo se vytvořit složku pro šablony",
     "%s used" : "%s použito",
     "%s%% of %s used" : "%s%% z %s použito",
     "%1$s of %2$s used" : "%1$s z %2$s použito",
-    "Settings" : "Nastavení",
+    "Files settings" : "Nastavení pro Soubory",
     "Show hidden files" : "Zobrazit skryté soubory",
+    "Crop image previews" : "Oříznout náhledy obrázků",
     "WebDAV" : "WebDAV",
     "Use this address to access your Files via WebDAV" : "Tuto adresu použijte pro přístup k vašim souborům prostřednictvím protokolu WebDAV",
+    "Toggle %1$s sublist" : "Přepnout %1$s podseznam",
     "Toggle grid view" : "Vyp/zap. zobrazení v mřížce",
     "No files in here" : "Žádné soubory",
-    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo synchronizujte se svými přístroji!",
+    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo proveďte synchronizaci se svými zařízeními!",
     "No entries found in this folder" : "V této složce nebylo nic nalezeno",
     "Select all" : "Vybrat vše",
     "Upload too large" : "Nahrávaná data jsou příliš objemná",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte nahrát, překračují limit velikosti nahrávání na tomto serveru.",
     "No favorites yet" : "Zatím nic oblíbeného",
     "Files and folders you mark as favorite will show up here" : "Zde budou zobrazeny soubory a složky, které označíte jako oblíbené",
-    "Deleted files" : "Odstraněné soubory",
+    "Deleted files" : "Smazané soubory",
     "Shares" : "Sdílení",
     "Shared with others" : "Sdíleno s ostatními",
     "Shared with you" : "Sdíleno s vámi",
@@ -191,19 +215,10 @@ OC.L10N.register(
     "Pending shares" : "Čekající sdílení",
     "Text file" : "Textový soubor",
     "New text file.txt" : "Nový textový soubor.txt",
-    "Unshare" : "Zrušit sdílení",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úložiště uživatele {owner} je téměř plné ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložiště je téměř plné ({usedSpacePercent}%)",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Soubor nebo složka byla <strong>změněna</strong> nebo <strong>přejmenována</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo složka",
-    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo složka byla <strong>smazána</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Upozorňovat na vytváření a změny pouze u vašich <strong>oblíbených souborů</strong> <em>(pouze v Proud)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Soubor nebo složka byla <strong>obnovena</strong>",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">přístup k vašim souborům přes WebDAV</a>",
-    "This group folder is full, files can not be updated or synced anymore!" : "Toto skupinová složka je plná, soubory už nadále už není aktualizovat nebo synchronizovat!",
-    "This external storage is full, files can not be updated or synced anymore!" : "Toto externí úložiště je plné, soubory už nadále už není aktualizovat nebo synchronizovat!",
-    "This group folder is almost full ({usedSpacePercent}%)" : "Tato skupinová složka je téměř plná ({usedSpacePercent}%)",
-    "This external storage is almost full ({usedSpacePercent}%)" : "Toto externí úložiště je téměř plné ({usedSpacePercent}%)",
-    "Cannot transfter ownership of a file or folder you don't own" : "Není možné převést vlastnictví souboru nebo složky, která vám nenáleží"
+    "Select" : "Vybrat",
+    "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo zde vytvářet soubory",
+    "New" : "Nový",
+    "Cannot transfer ownership of a file or folder you don't own" : "Není možné převést vlastnictví souboru či složky, které nejste vlastníky",
+    "Settings" : "Nastavení"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
