@@ -39,7 +39,12 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
     "Files" : "File",
     "Details" : "Dettagli",
-    "Select" : "Seleziona",
+    "Show list view" : "Commuta la vista a lista",
+    "Show grid view" : "Commuta la vista a griglia",
+    "Please select tag(s) to add to the selection" : "Seleziona un'etichetta(e) da aggiungere alla selezione",
+    "Apply tag(s) to selection" : "Applica etichetta(e) alla selezione",
+    "Select directory \"{dirName}\"" : "Seleziona cartella \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Seleziona file \"{fileName}\"",
     "Pending" : "In corso",
     "Unable to determine date" : "Impossibile determinare la data",
     "This operation is forbidden" : "Questa operazione è vietata",
@@ -65,13 +70,11 @@ OC.L10N.register(
     "Name" : "Nome",
     "Size" : "Dimensione",
     "Modified" : "Modificato",
-    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
-    "_%n file_::_%n files_" : ["%n file","%n file"],
+    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle","%n cartelle"],
+    "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
     "{dirs} and {files}" : "{dirs} e {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti"],
-    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
-    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
-    "New" : "Nuovo",
+    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti","inclusi %n nascosti"],
+    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso","Caricamento di %n file in corso"],
     "Select file range" : "Seleziona intervallo di file",
     "{used} of {quota} used" : "{used} di {quota} utilizzati",
     "{used} used" : "{used} utilizzati",
@@ -87,12 +90,12 @@ OC.L10N.register(
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\""],
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\"","verificano \"{filter}\""],
     "View in folder" : "Visualizza nella cartella",
     "Copied!" : "Copiato!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
     "Path" : "Percorso",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
+    "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
     "Favorited" : "Preferiti",
     "Favorite" : "Preferito",
     "You can only favorite a single file or folder at a time" : "Puoi aggiungere ai preferiti un singolo file o cartella alla volta",
@@ -168,7 +171,6 @@ OC.L10N.register(
     "Transfer {path} to {userid}" : "Trasferisci {path} a {userid}",
     "Invalid path selected" : "Percorso selezionato non valido",
     "Ownership transfer request sent" : "Richiesta di trasferimento della proprietà inviata",
-    "Cannot transfer ownership of a file or folder you don't own" : "Impossibile trasferire la proprietà di un file o di una cartella di altri",
     "Tags" : "Etichette",
     "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
     "Error while loading the file data" : "Errore durante il caricamento del file di dati",
@@ -185,7 +187,6 @@ OC.L10N.register(
     "%s used" : "%s utilizzato",
     "%s%% of %s used" : "%s%% di %s utilizzati",
     "%1$s of %2$s used" : "%1$s di %2$s utilizzati",
-    "Settings" : "Impostazioni",
     "Show hidden files" : "Mostra i file nascosti",
     "Crop image previews" : "Ritaglia le anteprime delle immagini",
     "WebDAV" : "WebDAV",
@@ -209,20 +210,10 @@ OC.L10N.register(
     "Pending shares" : "Condivisioni in corso",
     "Text file" : "File di testo",
     "New text file.txt" : "Nuovo file di testo.txt",
-    "Unshare" : "Rimuovi condivisione",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
-    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "La cartella di gruppo \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
-    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "L'archiviazione esterna \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%)",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
-    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un file o una cartella è stato <strong>modificato</strong> o <strong>rinominato</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
-    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>"
+    "Select" : "Seleziona",
+    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
+    "New" : "Nuovo",
+    "Cannot transfer ownership of a file or folder you don't own" : "Impossibile trasferire la proprietà di un file o di una cartella di altri",
+    "Settings" : "Impostazioni"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
