@@ -1,12 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "Migration pågår. Vänligen vänta tills migrationen är klar",
-    "Migration started …" : "Migrering påbörjad ...",
-    "Saved" : "Sparad",
-    "Not saved" : "Inte sparad",
-    "Sending…" : "Skickar...",
-    "Email sent" : "E-post skickad",
     "Private" : "Privat",
     "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer matchade via telefonnummer integration via Talk i mobilen",
     "Local" : "Lokal",
@@ -59,24 +53,21 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Fjärrensning startades på %1$s",
     "Remote wipe has finished on %1$s" : "Fjärrensning slutfördes på %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ditt <strong>lösenord</strong> eller <strong>e-postadress</strong> har ändrats",
-    "Couldn't remove app." : "Kunde inte ta bort applikationen.",
-    "Couldn't update app." : "Kunde inte uppdatera appen.",
     "Wrong password" : "Fel lösenord",
+    "Saved" : "Sparad",
     "No user supplied" : "Ingen användare angiven",
     "Authentication error" : "Fel vid autentisering",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Vänligen ange ett administratörs återställningslösenord; annars kommer alla användardata att försvinna.",
-    "Wrong admin recovery password. Please check the password and try again." : "Felaktigt återställningslösenord för administratör. Vänligen kontrollera lösenordet och prova igen.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Backend stödjer inte att lösenord ändras men användarens krypteringsnyckel uppdaterades.",
+    "Wrong admin recovery password. Please check the password and try again." : "Felaktigt återställningslösenord för administratör. Kontrollera lösenordet och prova igen.",
     "installing and updating apps via the App Store or Federated Cloud Sharing" : "installera och uppdatera appar via appbutiken eller federerad molndelning",
     "Federated Cloud Sharing" : "Federerad Moln-delning",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL använder en föråldrad %1$s version (%2$s). Uppdatera ditt operativsystem annars kommer inte funktioner som %3$s fungera pålitligt.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Kunde inte bestämma om TLS-versionen av cURL är för gammal eller inte för ett fel uppstod under HTTPS-förfrågan mot https://nextcloud.com. Vänligen kontrollera nextcloud loggfilen för fler detaljer.",
     "Invalid SMTP password." : "Ogiltigt SMTP-lösenord.",
     "Email setting test" : "E-postinställningar test",
     "Well done, %s!" : "Bra gjort, %s!",
     "If you received this email, the email configuration seems to be correct." : "Om du får detta e-postmeddelande så har du ställt in e-postinställningarna rätt.",
     "Email could not be sent. Check your mail server log" : "E-post kunde inte skickas. Titta i din e-postserverlogg",
-    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ett problem uppstod när e-post försökte skickas. Vänligen kontrollera dina inställningar. (Fel: %s)",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ett problem uppstod när e-post försökte skickas. Kontrollera dina inställningar. (Fel: %s)",
     "Invalid user" : "Ogiltig användare",
     "Invalid mail address" : "Ogiltig e-postadress",
     "Settings saved" : "Inställningar sparade",
@@ -132,14 +123,12 @@ OC.L10N.register(
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Ett bakgrundsjobb väntar som söker efter användarimporterade SSL-certifikat. Vänligen kontrollera igen senare.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Det finns några användarimporterade SSL-certifikat närvarande som inte längre används med Nextcloud 21. De kan importeras i kommandoraden via \"occ security:certificates:import\". Deras sökvägar inuti data-mappen visas nedanför.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MariaDB 10.2 or higher." : "MariaDB version \"%s\" används. Nextcloud 21 kommer inte längre stödja denna versionen och kräver MariaDB 10.2 eller högre.",
-    "MySQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" används. Nextcloud 21 kommer inte längre stödja denna versionen och kräver MySQL 8.0 eller MariaDB 10.2 eller högre.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" används. Nextcloud 21 kommer inte längre stödja denna versionen och kräver PostgreSQL 9.6 eller högre.",
     "Nextcloud settings" : "Nextcloud-inställningar",
     "Administration privileges" : "Administreringsprivilegier",
     "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken gruppen som har tillgång till vissa delar av administrationsinställningarna.",
     "None" : "Ingen",
     "Unable to modify setting" : "Kunde inte ändra inställning.",
+    "Two-Factor Authentication" : "Tvåfaktorsautentisering",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tvåfaktorsautentisering kan påtvingas för alla användare och specifika grupper. Om de inte har en tvåfaktorsleverantör konfigurerad kommer de inte att kunna logga in i systemet.",
     "Enforce two-factor authentication" : "Påtvinga tvåfaktorsautentisering",
     "Limit to groups" : "Begränsa till grupper",
@@ -170,7 +159,6 @@ OC.L10N.register(
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Utvalda appar utvecklas av och inom gemenskapen. De erbjuder central funktionalitet och är redo för produktionsanvändning.",
     "Featured" : "Utvalda",
     "Update to {update}" : "Uppdatera till {update}",
-    "Update all" : "Uppdatera alla",
     "Results from other categories" : "Resultat från andra kategorier",
     "No apps found for your version" : "Inga appar funna för din version",
     "Disable all" : "Inaktivera alla",
@@ -218,6 +206,19 @@ OC.L10N.register(
     "Copied!" : "Kopierad!",
     "Copy" : "Kopiera",
     "Could not copy app password. Please copy it manually." : "Det gick inte att kopiera applösenordet. Kopiera det manuellt.",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "För att köra detta behöver du PHP POSIX-tillägget. Se {linkstart}PHP dokumentation{linkend} för mer detaljer.",
+    "Profile" : "Profil",
+    "Enable" : "Aktivera",
+    "Server-side encryption" : "Serverkryptering",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering från servern möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
+    "Enable server-side encryption" : "Aktivera kryptering på server.",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "När kryptering är aktiverat, så kommer alla filer som laddas upp till servern från den tidpunkt och framåt bli krypterad på servern. Det kommer bara vara möjligt att inaktivera kryptering vid ett senare tillfälle om krypteringsmodulen stödjer den funktionen och alla förvillkor (exempelvis använder återställningsnyckel) är mötta.",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Enbart kryptering garanterar inte säkerhet i systemet. Se dokumentationen för ytterligare information om hur krypteringsappen fungerar, och de supporterade användarfallen.",
+    "Be aware that encryption always increases the file size." : "OBS! Observera att kryptering alltid ökar filstorleken",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det är alltid en god ide att skapa regelbundna säkerhetskopior av din data, om kryptering används var säker på att även krypteringsnycklarna säkerhetskopieras tillsammans med din data.",
+    "This is the final warning: Do you really want to enable encryption?" : "Detta är en slutgiltig varning: Vill du verkligen aktivera kryptering?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul inläst, aktivera krypteringsmodulen i applikationsmenyn.",
+    "Select default encryption module:" : "Välj krypteringsmodul:",
     "Remove group" : "Ta bort grupp",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Du håller på att ta bort gruppen {group}. Användarna kommer INTE att raderas.",
     "Please confirm the group removal " : "Bekräfta borttagning av gruppen",
@@ -331,6 +332,9 @@ OC.L10N.register(
     "Show user backend" : "Visa användar-backend",
     "Show storage path" : "Visa lagringsväg",
     "Send email to new user" : "Skicka e-post till ny användare",
+    "Not saved" : "Inte sparad",
+    "Sending…" : "Skickar...",
+    "Email sent" : "E-post skickad",
     "Address" : "Ort/Stad",
     "Avatar" : "Avatar",
     "About" : "Om",
@@ -339,7 +343,6 @@ OC.L10N.register(
     "Headline" : "Rubrik",
     "Organisation" : "Organisation",
     "Phone number" : "Telefonnummer",
-    "Profile" : "Profil",
     "Role" : "Roll",
     "Twitter" : "Twitter",
     "Website" : "Webbplats",
@@ -350,14 +353,12 @@ OC.L10N.register(
     "Show to logged in users only" : "Visa endast för inloggade användare",
     "Hide" : "Dölj",
     "Download and enable" : "Hämta och aktivera",
-    "Enable" : "Aktivera",
     "Enable untested app" : "Aktivera otestad app",
     "The app will be downloaded from the App Store" : "Appen kommer hämtas från appbutiken",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
     "Never" : "Aldrig",
     "An error occured during the request. Unable to proceed." : "Ett fel uppstod under förfrågan. Kan inte fortsätta.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen har aktiverats men måste uppdateras. Du kommer att omdirigeras till uppdateringssidan om 5 sekunder.",
-    "App update" : "Appuppdatering",
     "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil",
     "Administrator documentation" : "Administratörsdokumentation",
     "Documentation" : "Dokumentation",
@@ -390,34 +391,6 @@ OC.L10N.register(
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Vänligen dubbelkolla <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installationsguiderna ↗</a>, och leta efter eventuella fel eller varningar i <a href=\"%2$s\">loggen</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrollera säkerheten för ditt Nextcloud över <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår säkerhetsgenomsökning ↗</a>.",
     "Version" : "Version",
-    "Two-Factor Authentication" : "Tvåfaktorsautentisering",
-    "Server-side encryption" : "Serverkryptering",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering från servern möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
-    "Enable server-side encryption" : "Aktivera kryptering på server.",
-    "Please read carefully before activating server-side encryption: " : "Vänligen läs noga innan du aktiverar kryptering på serversidan: ",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "När kryptering är aktiverat, så kommer alla filer som laddas upp till servern från den tidpunkt och framåt bli krypterad på servern. Det kommer bara vara möjligt att inaktivera kryptering vid ett senare tillfälle om krypteringsmodulen stödjer den funktionen och alla förvillkor (exempelvis använder återställningsnyckel) är mötta.",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Enbart kryptering garanterar inte säkerhet i systemet. Vänligen se dokumentationen för ytterligare information om hur krypteringsappen fungerar, och de supporterade användarfallen.",
-    "Be aware that encryption always increases the file size." : "OBS! Observera att kryptering alltid ökar filstorleken",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det är alltid en god ide att skapa regelbundna säkerhetskopior av din data, om kryptering används var säker på att även krypteringsnycklarna säkerhetskopieras tillsammans med din data.",
-    "This is the final warning: Do you really want to enable encryption?" : "Detta är en slutgiltig varning: Vill du verkligen aktivera kryptering?",
-    "Enable encryption" : "Aktivera kryptering",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul inläst, vänligen aktivera krypteringsmodulen i applikationsmenyn.",
-    "Select default encryption module:" : "Välj krypteringsmodul:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya. Vänligen aktivera \"Standard krypteringsmodul\" och kör 'occ encryption:migrate'.",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya.",
-    "Start migration" : "Starta migrering",
-    "Last job execution ran %s. Something seems wrong." : "Sista jobbexekveringen körde %s. Något verkar vara fel.",
-    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Vissa jobb har inte utförts sedan %s. Överväg att justera tid för exekvering.",
-    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Vissa jobb utfördes inte sedan %s. Överväg att byta till system cron.",
-    "Last job ran %s." : "Senaste jobbet kördes %s.",
-    "Background job didn’t run yet!" : "Bakgrundsjobb har inte kört ännu!",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "För optimal prestanda är det viktigt att konfigurera bakgrundsjobb korrekt. För större instanser 'Cron' är den rekommenderade inställningen. Vänligen se dokumentationen för mer information.",
-    "Pick background job setting" : "Välj inställning för bakgrundsjobb",
-    "Execute one task with each page loaded." : "Utför en uppgift med varje sida inläst.",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php är registrerat hos en webcron-tjänst att köra cron.php var 5: e minut över HTTP.",
-    "Use system cron service to call the cron.php file every 5 minutes." : "Använd systemets cron-tjänst för att anropa cron.php var 5: e minut.",
-    "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php behöver exekveras av systemanvändaren \"%s\".",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "För att köra detta behöver du PHP POSIX-tillägget. Se {linkstart}PHP dokumentation{linkend} för mer detaljer.",
     "You need to enable the File sharing App." : "Du måste aktivera fildelnings-appen.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du fininställa delningsbeteendet. Vänligen se dokumentationen för mer information.",
     "Allow apps to use the Share API" : "Tillåt applikationer att använda API för delning",
@@ -441,7 +414,6 @@ OC.L10N.register(
     "Allow username autocompletion to users within the same groups" : "Tillåt autokomplettering av användarnamn till användare inom samma grupper",
     "Allow username autocompletion to users based on phone number integration" : "Tillåt autokomplettering av användarnamn till användare baserad på telefonnummerintegration",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Om komplettering för \"samma grupp\" och \"telefonnummerintegration\" är aktiverade räcker det med en matchning i en av dem för att visa användaren.",
-    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt komplettering av användarnamn vid ifyllning av fullständigt namn eller e-postadress (bortser från saknande matchning i telefonboken eller grupptillhörighet i samma grupp)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Visa friskrivningstext på offentliga uppladdningssidan (visas endast när fil-listan är gömd)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Denna text kommer att visa på den offentliga uppladdnings-sidan när fil-listan är gömd.",
     "Default share permissions" : "Standardrättigheter för delning",
@@ -479,34 +451,35 @@ OC.L10N.register(
     "Change password" : "Ändra lösenord",
     "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor förutom ditt lösenord för att öka säkerheten för ditt konto.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
-    "Don't synchronize to servers" : "Synkronisera inte till servrar",
-    "Trusted" : "Betrodd",
-    "Public" : "Offentlig",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "installerar och uppdaterar appar via appbutiken eller federerad molndelning",
+    "Migration in progress. Please wait until the migration is finished" : "Migration pågår. Vänta tills migrationen är klar",
+    "Migration started …" : "Migrering påbörjad ...",
+    "Couldn't remove app." : "Kunde inte ta bort applikationen.",
+    "Couldn't update app." : "Kunde inte uppdatera appen.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Backend stödjer inte att lösenord ändras men användarens krypteringsnyckel uppdaterades.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Kunde inte bestämma om TLS-versionen av cURL är för gammal eller inte för ett fel uppstod under HTTPS-förfrågan mot https://nextcloud.com. Vänligen kontrollera nextcloud loggfilen för fler detaljer.",
     "You need to set your user email before being able to send test emails." : "Du behöver ställa in din användares e-postadress före du kan skicka test e-post.",
     "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Återkallning kan förhindra att enheten rensas om inte rensningen redan har startat.",
-    "Nextcloud iOS app" : "Nextcloud iOS-app",
-    "Nextcloud Android app" : "Nextcloud Android-app",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk för iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk för Android",
-    "Add user in group" : "Lägg till användare i grupp",
-    "Close" : "Stäng",
+    "Set as primary mail" : "Sätt som primär e-postadress",
+    "Change privacy level of email" : "Ändra hemlighetsnivå för e-post",
     "All languages" : "Alla språk",
     "Everyone" : "Alla",
-    "The app will be downloaded from the app store" : "Appen kommer hämtas från appbutiken",
-    "Error: This app can not be enabled because it makes the server unstable" : "Fel: Denna app kan inte aktiveras eftersom det gör servern instabil",
-    "mail" : "e-post",
     "Test email settings" : "Testa e-postinställningar",
-    "Expire after " : "Förfaller efter",
+    "Please read carefully before activating server-side encryption: " : "Läs noga innan du aktiverar kryptering på serversidan: ",
+    "Enable encryption" : "Aktivera kryptering",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya. Aktivera \"Standard krypteringsmodul\" och kör 'occ encryption:migrate'.",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya.",
+    "Start migration" : "Starta migrering",
+    "Last job execution ran %s. Something seems wrong." : "Sista jobbexekveringen körde %s. Något verkar vara fel.",
+    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Vissa jobb har inte utförts sedan %s. Överväg att justera tid för exekvering.",
+    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Vissa jobb utfördes inte sedan %s. Överväg att byta till system cron.",
+    "Last job ran %s." : "Senaste jobbet kördes %s.",
+    "Background job didn’t run yet!" : "Bakgrundsjobb har inte kört ännu!",
+    "Pick background job setting" : "Välj inställning för bakgrundsjobb",
+    "Recommended" : "Rekomenderad",
+    "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php behöver exekveras av systemanvändaren \"%s\".",
     "days" : "dagar",
-    "Allow users to share via link" : "Tillåt användare att dela via länk",
-    "Set default expiration date for link shares" : "Ställ in standardutgångsdatum för länkade delningar",
-    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Tillåt autokomplettering av användarnamn i delningsdialogen (om detta är inaktiverat måste fullständigt användarnamn eller e-postadress anges)",
-    "Restrict username autocompletion to users within the same groups" : "Begränsa prediktion av användarnamn till användare inom samma grupper.",
-    "No display name set" : "Inget visningsnamn angivet",
-    "For password reset and notifications" : "För lösenordsåterställning och aviseringar",
+    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt komplettering av användarnamn vid ifyllning av fullständigt namn eller e-postadress (bortser från saknande matchning i telefonboken eller grupptillhörighet i samma grupp)",
     "Change privacy level of full name" : "Ändra hemlighetsnivå för helt namn",
-    "Change privacy level of email" : "Ändra hemlighetsnivå för e-post",
-    "Set as primary mail" : "Sätt som primär e-postadress"
+    "No display name set" : "Inget visningsnamn angivet"
 },
 "nplurals=2; plural=(n != 1);");
