@@ -35,9 +35,13 @@ OC.L10N.register(
     "Entity %s has no event %s" : "Die Entität %s hat kein Ereignis %s",
     "Operation %s does not exist" : "Operation %s existert nicht",
     "Operation %s is invalid" : "Operation %s ist ungültig",
+    "At least one check needs to be provided" : "Mindestens ein Test muss bereitgestellt werden",
+    "The provided operation data is too long" : "Die bereitgestellten Betriebsdaten sind zu lang",
+    "Invalid check provided" : "Ungültiger Test bereitgestellt",
     "Check %s does not exist" : "Die Prüfung %s existiert nicht",
     "Check %s is invalid" : "Die Prüfung %s ist ungültig",
     "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
+    "The provided check value is too long" : "Der bereitgestellte Prüfwert ist zu lang",
     "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
     "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
     "Flow" : "Ablauf",
@@ -45,17 +49,19 @@ OC.L10N.register(
     "Select a filter" : "Filter auswählen",
     "Select a comparator" : "Wähle einen Komparator",
     "Select a file type" : "Dateityp auswählen",
-    "e.g. httpd/unix-directory" : "z.B. httpd/unix-directory",
+    "e.g. httpd/unix-directory" : "z. B. httpd/unix-directory",
+    "Folder" : "Ordner",
     "Images" : "Bilder",
     "Office documents" : "Office Dokumente",
     "PDF documents" : "PDF-Dokumente",
+    "Custom MIME type" : "Benutzerdefinierter MIME Typ",
     "Custom mimetype" : "Benutzerdefinierter Mime-Typ",
     "Select a tag" : "Schlagwort auswählen",
     "No results" : "Keine Ergebnisse",
     "%s (invisible)" : "%s(unsichtbar)",
     "%s (restricted)" : "%s (eingeschränkt)",
     "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
-    "Select a request URL" : "Wählen Sie eine Anforderungs-URL aus",
+    "Select a request URL" : "Wähle eine Anforderungs-URL aus",
     "Predefined URLs" : "Vordefinierte URLs",
     "Files WebDAV" : "WebDAV für Dateien",
     "Others" : "Andere",
@@ -64,8 +70,9 @@ OC.L10N.register(
     "Android client" : "Android-Client",
     "iOS client" : "iOS-Client",
     "Desktop client" : "Desktop-Client",
-    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
+    "Thunderbird & Outlook addons" : "Thunderbird & Outlook Add-ons",
     "Custom user agent" : "Benutzerdefinierter User-Agent",
+    "At least one event must be selected" : "Mindestens ein Termin muss ausgewählt werden",
     "Add new flow" : "Neuen Ablauf hinzufügen",
     "When" : "Wenn",
     "and" : "und",
@@ -75,18 +82,18 @@ OC.L10N.register(
     "Active" : "Aktiv",
     "Save" : "Speichern",
     "Available flows" : "Verfügbare Abläufe",
-    "For details on how to write your own flow, check out the development documentation." : "Informationen wie eigene Abläufe erstellt werden, findest Du in der Entwickler-Dokumentation.",
+    "For details on how to write your own flow, check out the development documentation." : "Informationen wie eigene Abläufe erstellt werden, findest du in der Entwickler-Dokumentation.",
     "More flows" : "Weitere Abläufe",
-    "Browse the app store" : "Appstore durchsuchen",
+    "Browse the App Store" : "App-Store durchsuchen",
     "Show less" : "Weniger anzeigen",
     "Show more" : "Mehr anzeigen",
     "Configured flows" : "Konfigurierte Abläufe",
     "Your flows" : "Deine Abläufe",
-    "File name" : "Dateiname",
-    "is" : "ist",
-    "is not" : "ist nicht",
     "matches" : "entspricht",
     "does not match" : "entspricht nicht",
+    "is" : "ist",
+    "is not" : "ist nicht",
+    "File name" : "Dateiname",
     "File MIME type" : "Datei MIME-Typ",
     "File size (upload)" : "Dateigröße (beim Hochladen)",
     "less" : "weniger",
@@ -108,26 +115,6 @@ OC.L10N.register(
     "Request user agent" : "User-Agent",
     "User group membership" : "Benutzergruppen-Mitgliedschaft",
     "is member of" : "ist Mitglied von",
-    "is not member of" : "ist kein Mitglied von",
-    "Short rule description" : "Kurze Regelbeschreibung",
-    "Add rule" : "Regel hinzufügen",
-    "Reset" : "Zurücksetzen",
-    "Saving…" : "Speichern…",
-    "Group list is empty" : "Gruppenliste ist leer",
-    "Unable to retrieve the group list" : "Gruppenliste konnte nicht empfangen werden",
-    "Saved" : "Gespeichert",
-    "Saving failed:" : "Speichern fehlgeschlagen:",
-    "Add rule group" : "Regelgruppe hinzufügen",
-    "Example: {placeholder}" : "Beispiel: {placeholder}",
-    "Select tag…" : "Wähle einen Tag…",
-    "Start" : "Start",
-    "End" : "Ende",
-    "Select timezone…" : "Wähle eine Zeitzone…",
-    "Sync clients" : "Sync-Clients",
-    "Workflow" : "Arbeitsablauf",
-    "Files workflow engine" : "Datei-Arbeitsablauf-Engine",
-    "Open documentation" : "Dokumentation öffnen",
-    "Loading…" : "Laden…",
-    "Tag management" : "Schlagwortverwaltung"
+    "is not member of" : "ist kein Mitglied von"
 },
 "nplurals=2; plural=(n != 1);");
