@@ -2,14 +2,11 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "לא ניתן לכתוב לתיקיית „config”!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "בדרך כלל ניתן לפתור את הבעיה על ידי כך שנותנים לתכנית השרת הרשאות כתיבה לתיקיית config",
     "See %s" : "יש לעיין ב־%s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "או, אם עדיף לך לשמור על config.php לקריאה בלבד, ניתן להגדיר את האפשרות „config_is_read_only” לערך true.",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית ההגדרות. נא לעיין ב־%s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "או, אם עדיף לך לשמור על config.php לקריאה בלבד, ניתן להגדיר את האפשרות „config_is_read_only” לערך true. נא לעיין ב־%s",
-    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "הקבצים של היישומון %$1s לא הוחלפו כראוי. נא לוודא שגרסה זו תואמת לזו של השרת.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "הקבצים של היישומון %1$s לא מוקמו במקום הנכון. נא לוודא שזו גרסה שהשרת תומך בה.",
     "Sample configuration detected" : "התגלתה דוגמת תצורה",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "התגלה שדוגמת התצורה הועתקה. דבר זה עלול לשבור את ההתקנה ולא נתמך.יש לקרוא את מסמכי התיעוד לפני שמבצעים שינויים ב- config.php",
+    "Other activities" : "פעילויות אחרות",
     "Education Edition" : "מהדורה חינוכית",
     "Enterprise bundle" : "מהדורה מסחרית",
     "Groupware bundle" : "מהדורה קבוצתית",
@@ -17,13 +14,16 @@ OC.L10N.register(
     "PHP %s or higher is required." : "נדרש PHP בגרסת %s ומעלה.",
     "PHP with a version lower than %s is required." : "נדרש PHP בגרסה נמוכה מ- %s.",
     "%sbit or higher PHP required." : "נדרש PHP בגרסת %s ומעלה.",
-    "Following databases are supported: %s" : "מסדי הנתונים הבאים נתמכים: %s",
+    "The following architectures are supported: %s" : "קיימת תמיכה בתצורות המעבדים הבאות: %s",
+    "The following databases are supported: %s" : "יש תמיכה במסדי הנתונים הבאים: %s",
     "The command line tool %s could not be found" : "כלי שורת הפקודה %s לא אותר",
     "The library %s is not available." : "הספריה %s אינה זמינה.",
-    "Following platforms are supported: %s" : "הפלטפורמות הבאות נתמכות: %s",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "נדרשת ספרייה %1$s עם גרסה מתחת ל־%2$s - הגרסה הזמינה היא %3$s.",
+    "The following platforms are supported: %s" : "קיימת תמיכה בפלטפורמות הבאות: %s",
     "Server version %s or higher is required." : "נדרשת גרסה שרת %s ומעלה.",
     "Server version %s or lower is required." : "נדרשת גרסה שרת %s ומטה.",
     "Logged in user must be an admin" : "על המשתמש שנכנס להיות מנהל",
+    "Authentication" : "אימות",
     "Unknown filetype" : "סוג קובץ לא מוכר",
     "Invalid image" : "תמונה לא חוקית",
     "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
@@ -45,8 +45,9 @@ OC.L10N.register(
     "_in %n minute_::_in %n minutes_" : ["בעוד דקה","בעוד 2 דקות","בעוד %n דקות","בעוד %n דקות"],
     "_%n minute ago_::_%n minutes ago_" : ["לפני דקה","לפני 2 דקות","לפני %n דקות","לפני %n דקות"],
     "in a few seconds" : "בעוד מספר שניות",
-    "seconds ago" : "שניות",
+    "seconds ago" : "לפני מספר שניות",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "המודול עם המזהה: %s לא קיים. נא להפעיל אותו בהגדרות היישומונים שלך או ליצור קשר עם מנהל המערכת.",
+    "File already exists" : "הקובץ כבר קיים",
     "File name is a reserved word" : "שם קובץ הוא מילה שמורה",
     "File name contains at least one invalid character" : "שם הקובץ כולל לפחות תו אחד לא חוקי",
     "File name is too long" : "שם קובץ ארוך מדי",
@@ -61,60 +62,45 @@ OC.L10N.register(
     "Settings" : "הגדרות",
     "Log out" : "התנתק",
     "Users" : "משתמשים",
+    "Email" : "דוא״ל",
+    "Phone" : "טלפון",
+    "Twitter" : "טוויטר",
+    "Website" : "אתר אינטרנט",
+    "Address" : "כתובת",
+    "Profile picture" : "תמונת פרופיל",
+    "About" : "על אודות",
+    "Full name" : "שם מלא",
     "Unknown user" : "משתמש לא ידוע",
-    "Create" : "יצירה",
-    "Change" : "שינוי",
-    "Delete" : "מחיקה",
-    "Share" : "שיתוף",
-    "Overview" : "סקירה",
-    "Basic settings" : "הגדרות בסיסיות",
-    "Sharing" : "שיתוף",
-    "Security" : "אבטחה",
-    "Groupware" : "קבוצתי",
     "Additional settings" : "הגדרות נוספות",
-    "Personal info" : "פרטים אישיים",
-    "Mobile & desktop" : "נייד ושולחן עבודה",
-    "Unlimited" : "ללא הגבלה",
-    "Verifying" : "מתבצע אימות",
-    "Verifying …" : "מתבצע אימות…",
-    "Verify" : "אימות",
     "%s enter the database username and name." : "%s יש להכניס את שם המשתמש ושם מסד הנתונים.",
     "%s enter the database username." : "%s נכנס למסד נתוני שמות המשתמשים.",
     "%s enter the database name." : "%s נכנס למסד נתוני השמות.",
     "%s you may not use dots in the database name" : "%s לא ניתן להשתמש בנקודות בשם מסד הנתונים",
+    "MySQL username and/or password not valid" : "שם המשתמש ו/או הססמה של MySQL אינם תקינים",
+    "You need to enter details of an existing account." : "עליך להקליד פרטים של חשבון קיים.",
     "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
     "Oracle username and/or password not valid" : "שם משתמש ו/או סיסמת Oracle אינם תקפים",
     "PostgreSQL username and/or password not valid" : "שם משתמש ו/או סיסמת PostgreSQL אינם תקפים",
-    "You need to enter details of an existing account." : "עליך להקליד פרטים של חשבון קיים.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X אינו נתמך ו- %s לא יעבוד כשורה בפלטפורמה זו. ניתן לקחת סיכון ולהשתמש באחריותך! ",
     "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
     "Set an admin username." : "קביעת שם משתמש מנהל",
     "Set an admin password." : "קביעת סיסמת מנהל",
-    "Can't create or write into the data directory %s" : "לא ניתן ליצור או לכתוב לתוך תיקיית הנתונים %s",
-    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "השיתוף %s נכשל, כיוון שהצד האחורי אינו מאפשר שיתופים מסוג %i",
-    "Sharing %s failed, because the file does not exist" : "השיתוף %s נכשל, כיוון שהקובץ אינו קיים",
-    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
-    "Sharing %s failed, because you can not share with yourself" : "השיתוף %s נכשל, כיוון שלא ניתן לשתף עם עצמך",
-    "You need to provide a password to create a public link, only protected links are allowed" : "יש לספק סיסמא ליצירת קישור ציבורי, רק קישורים מוגנים מותרים",
-    "Sharing %s failed, because sharing with links is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף עם קישור אינו מותר",
-    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "לא ניתן לקבוע תאריך תפוגה. שיתופים אינם יכולים לפוג תוקף מאוחר יותר מ- %s לאחר ששותפו",
-    "Cannot set expiration date. Expiration date is in the past" : "לא ניתן לקבוע תאריך תפוגה. תאריך התפוגה הנו בעבר",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
     "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
     "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
-    "Sharing failed, because the user %s is the original sharer" : "שיתוף נכשל, כיוון שמשתמש %s הנו המשתף המקורי",
-    "Sharing %s failed, because resharing is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף מחודש אסור",
-    "Sharing %s failed, because the file could not be found in the file cache" : "השיתוף %s נכשל, כייון שלא ניתן היה למצוא את הקובץ בזכרון המטמון",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s שיתף » %2$s« איתך, ורוצה להוסיף:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$sשיתף »%2$s« איתך, ורוצה להוסיף:",
+    "»%s« added a note to a file shared with you" : "התווספה הערה על קובץ ששותף את על ידי „%s”",
     "Open »%s«" : "פתיחת „%s”",
-    "Can’t increase permissions of %s" : "לא ניתן לחזק את ההרשאות של %s",
-    "Files can’t be shared with delete permissions" : "לא ניתן לשתף קבצים עם הרשאת מחיקה",
-    "Files can’t be shared with create permissions" : "לא ניתן לשתף קבצים עם הרשאות יצירה",
+    "%1$s via %2$s" : "%1$s דרך %2$s",
+    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
+    "Cannot increase permissions of %s" : "לא ניתן להוסיף על ההרשאות של %s",
     "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
-    "Can’t set expiration date more than %s days in the future" : "לא ניתן להגדיר את תאריך התפוגה מעל %s ימים בעתיד",
+    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
+    "%1$s shared »%2$s« with you" : "%2$s שותף אתך על ידי %1$s",
+    "%1$s shared »%2$s« with you." : "„%2$s” שותף אתך על ידי %1$s.",
     "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
     "The requested share does not exist anymore" : "השיתוף המבוקש אינו קיים עוד",
     "Could not find category \"%s\"" : "לא ניתן למצוא את הקטגוריה „%s“",
@@ -163,10 +149,12 @@ OC.L10N.register(
     "Oct." : "אוק׳",
     "Nov." : "נוב׳",
     "Dec." : "דצמ׳",
+    "The user limit has been reached and the user was not created." : "הגעת למגבלת המשתמשים והמשתמש לא נוצר.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "רק התווים הבאים מאושרים לשם משתמש: \"a-z\", \"A-Z\", \"0-9\", וגם \"_.@-'\"",
     "A valid username must be provided" : "יש לספק שם משתמש תקני",
     "Username contains whitespace at the beginning or at the end" : "שם המשתמש מכיל רווח בתחילתו או בסופו",
     "Username must not consist of dots only" : "שם המשתמש לא יכול להיות מורכב מנקודות בלבד",
+    "Username is invalid because files already exist for this user" : "שם המשתמש שגוי כיוון שכבר קיימים קבצים למשתמש הזה",
     "A valid password must be provided" : "יש לספק ססמה תקנית",
     "The username is already being used" : "השם משתמש כבר בשימוש",
     "Could not create user" : "לא ניתן ליצור משתמש",
@@ -174,38 +162,22 @@ OC.L10N.register(
     "Login canceled by app" : "התחברות בוטלה על ידי יישום",
     "a safe home for all your data" : "בית בטוח עבור כל המידע שלך",
     "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר",
-    "Can't read file" : "לא ניתן לקרוא קובץ",
     "Application is not enabled" : "יישומים אינם מופעלים",
     "Authentication error" : "שגיאת הזדהות",
     "Token expired. Please reload page." : "פג תוקף. נא לטעון שוב את הדף.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "לא מותקנים דרייברים למסד הנתונים (sqlite, mysql, או postgresql).",
-    "Cannot write into \"config\" directory" : "לא ניתן לכתוב לתיקיית \"config\"!",
-    "Cannot write into \"apps\" directory" : "לא ניתן לכתוב לתיקיית \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית היישומונים או להשבית את חנות היישומונים בקובץ ההגדרות. נא לעיין ב־%s",
-    "Cannot create \"data\" directory" : "לא ניתן ליצור תיקיית „data”",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית הבסיס. נא לעיין ב־%s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "בדרך כלל ניתן לתקן הרשאות על ידי מתן גישה לשרת שלך אל תיקיית העל. נא לעיין ב־%s.",
-    "Setting locale to %s failed" : "הגדרת שפה ל- %s נכשלה",
-    "Please install one of these locales on your system and restart your webserver." : "יש להתקין אחת מהשפות על המערכת שלך ולהפעיל מחדש את שרת האינטרנט.",
-    "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "או, אם עדיף לך לשמור על config.php לקריאה בלבד, ניתן להגדיר את האפשרות „config_is_read_only” לערך true. נא לעיין ב־%s",
     "PHP module %s not installed." : "מודול PHP %s אינו מותקן.",
+    "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
     "PHP setting \"%s\" is not set to \"%s\"." : "הגדרות PHP \"%s\" אינם מוגדרות ל- \"%s\"",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "התאמת ההגדרה הזו ב־php.ini יאפשר ל־Nextcloud לפעול שוב",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload מוגדר ל- \"%s\" במקום הערך המצופה \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "לתיקון בעיה זו יש להגדיר <code>mbstring.func_overload</code> כ- <code>0</code> iבקובץ ה- php.ini שלך",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 נדרש לכל הפחות. כרגע %s מותקן.",
     "To fix this issue update your libxml2 version and restart your web server." : "לתיקון הבעיה יש לעדכן את גרסת ה- libxml2 שלך ולהפעיל מחדש את שרת האינטרנט שלך.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ככל הנראה מוגדר ל- strip inline doc blocks. זה יגרום למספר יישומי ליבה לא להיות נגישים.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
     "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
-    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
-    "Please upgrade your database version" : "יש לשדרג את גרסת מסד הנתונים שלך",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
-    "Your data directory is readable by other users" : "תיקיית הנתונים שלך ניתנת לקריאה על ידי משתמשים אחרים",
-    "Your data directory must be an absolute path" : "תיקיית הנתונים שלך חייבת להיות במבנה של נתיב מלא (מיקום מוחלט)",
-    "Check the value of \"datadirectory\" in your configuration" : "יש לבדוק את הערך \"datadirectory\" בהגדרות התצורה שלך",
-    "Your data directory is invalid" : "תיקיית הנתונים שלך שגויה",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "נא לוודא שיש קובץ בשם „‎.ocdata” בבסיס תיקיית הנתונים שלך.",
     "Action \"%s\" not supported or implemented." : "הפעולה „%s” אינה נתמכת או שאינה מוטמעת.",
     "Authentication failed, wrong token or provider ID given" : "האימות נכשל, האסימון או מזהה הספק שסופקו שגויים",
@@ -216,39 +188,22 @@ OC.L10N.register(
     "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
     "Storage is temporarily not available" : "האחסון אינו זמין כרגע",
     "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "ספריה %s בגרסה גבוהה מ- %s נדרשת - גרסה זמינה %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "ספריה %s בגרסה נמוכה מ- %s נדרשת - גרסה זמינה %s.",
-    "Personal" : "אישי",
-    "Admin" : "מנהל",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Encryption" : "הצפנה",
-    "Tips & tricks" : "טיפים וטריקים",
-    "DB Error: \"%s\"" : "שגיאת מסד נתונים: „%s”",
-    "Offending command was: \"%s\"" : "הפקודה הסוררת הייתה: „%s”",
-    "Offending command was: \"%s\", name: %s, password: %s" : "הפקודה הסוררת הייתה: „%s”, שם: %s, ססמה: %s",
-    "Sharing %s failed, because the user %s does not exist" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו קיים",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו חבר בקבוצות ש- %s חבר ב-",
-    "Sharing %s failed, because this item is already shared with %s" : "שיתוף %s נכשל, כיוון שפריט זה כבר משותף עם %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
-    "Sharing %s failed, because the group %s does not exist" : "השיתוף %s נכשל, כיוון שהקבוצה %s אינה קיימת",
-    "Sharing %s failed, because %s is not a member of the group %s" : "השיתוף %s נכשל, כיוון ש- %s אינו חבר בקבוצה %s",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "שיתוף %s נכשל, לא ניתן לאתר %s, ייתכן שהשרת לא ניתן להשגה כרגע.",
-    "Share type %s is not valid for %s" : "שיתוף מסוג %s אינו תקף ל- %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "הגדרות ההרשאות עבור %s נכשלה, כיוון שההרשאות חורגות מההרשאות שהוענקו ל־%s ",
-    "Setting permissions for %s failed, because the item was not found" : "הגדרת ההרשאות עבור %s נכשלה, כיוון שהפריט לא נמצא",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "לא ניתן למחוק את מועד התפוגה. לשיתופים צריך להיות מועד תפוגה.",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "השיתוף %s נכשל, כיוון שההרשאות עלו על ההרשאות שניתנו ל- %s",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "השיתוף %s נכשל, כיוון שבצד אחורי לשיתוף עבור %s לא ניתן היה לאתר את מקורו",
-    "Cannot increase permissions of %s" : "לא ניתן להוסיף על ההרשאות של %s",
-    "Files can't be shared with delete permissions" : "אי אפשר לשתף קבצים עם הרשאות מחיקה",
-    "Files can't be shared with create permissions" : "אי אפשר לשתף קבצים עם הרשאות יצירה",
-    "Cannot set expiration date more than %s days in the future" : "לא ניתן להגדיר מועד תפוגה של למעלה מ־%s ימים בעתיד",
-    "%s shared »%s« with you" : "%s שיתף/שיתפה איתך את »%s«",
-    "%s via %s" : "%s על בסיס %s",
-    "No app name specified" : "לא צוין שם יישומון",
-    "App '%s' could not be installed!" : "לא ניתן להתקין את היישומון ‚%s’!",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "היישום \"%s\" לא ניתן להתקנה כיוון שיחסי התלות הבאים אינם מתקיימים: %s",
-    "Sync clients" : "סנכרון לקוחות"
+    "This can usually be fixed by giving the webserver write access to the config directory." : "בדרך כלל ניתן לתקן זאת על ידי מתן גישת כתיבה לשרת לתיקיית ההגדרות (config).",
+    "Cannot write into \"config\" directory" : "לא ניתן לכתוב לתיקיית \"config\"!",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית ההגדרות. נא לעיין ב־%s",
+    "Cannot write into \"apps\" directory" : "לא ניתן לכתוב לתיקיית \"apps\"",
+    "Cannot create \"data\" directory" : "לא ניתן ליצור תיקיית „data”",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "בדרך כלל ניתן לתקן זאת על ידי הענקת גישה לשרת לכתוב לתיקיית הבסיס. נא לעיין ב־%s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "בדרך כלל ניתן לתקן הרשאות על ידי מתן גישה לשרת שלך אל תיקיית העל. נא לעיין ב־%s.",
+    "Setting locale to %s failed" : "הגדרת שפה ל- %s נכשלה",
+    "Please install one of these locales on your system and restart your webserver." : "יש להתקין אחת מהשפות על המערכת שלך ולהפעיל מחדש את שרת האינטרנט.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload מוגדר ל- \"%s\" במקום הערך המצופה \"0\"",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "לתיקון בעיה זו יש להגדיר <code>mbstring.func_overload</code> כ- <code>0</code> iבקובץ ה- php.ini שלך",
+    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
+    "Please upgrade your database version" : "יש לשדרג את גרסת מסד הנתונים שלך",
+    "Your data directory is readable by other users" : "תיקיית הנתונים שלך ניתנת לקריאה על ידי משתמשים אחרים",
+    "Your data directory must be an absolute path" : "תיקיית הנתונים שלך חייבת להיות במבנה של נתיב מלא (מיקום מוחלט)",
+    "Check the value of \"datadirectory\" in your configuration" : "יש לבדוק את הערך \"datadirectory\" בהגדרות התצורה שלך",
+    "Your data directory is invalid" : "תיקיית הנתונים שלך שגויה"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
