@@ -2,12 +2,18 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Nie je možné zapisovat do priečinka \"config\"!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do priečinka s konfiguráciou.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s konfiguráciou.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Alebo, ak preferujete ponechať súbor config.php iba na čítanie, nastavte v ňom parameter \"config_is_read_only\" na true.",
     "See %s" : "Pozri %s",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do adresára s konfiguráciou. Viď %s",
-    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Súbory aplikácie %$1s nebolo možné úspešne nahradiť. Uistite sa, že verzia je kompatibilná s verziou servera.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Súbory aplikácie %1$s neboli správne nahradené. Uistite sa, že to je verzia kompatibilná so serverom.",
     "Sample configuration detected" : "Detekovaná bola vzorová konfigurácia",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zistilo sa, že konfigurácia bola skopírovaná zo vzorových súborov. Takáto konfigurácia nie je podporovaná a môže poškodiť vašu inštaláciu. Prečítajte si dokumentáciu pred vykonaním zmien v config.php",
+    "%s email verification" : "%s overenie e-mailu",
+    "Email verification" : "Overenie e-mailu",
+    "Click the following button to confirm your email." : "Kliknite na tlačítko pre potvrdenie vašeho e-mailu.",
+    "Click the following link to confirm your email." : "Kliknite na odkaz pre potvrdenie vašeho e-mailu.",
+    "Confirm your email" : "Potvrďte svoj e-mail",
+    "Other activities" : "Iné aktivity",
     "%1$s and %2$s" : "%1$s a %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s a %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s a %4$s",
@@ -15,41 +21,65 @@ OC.L10N.register(
     "Education Edition" : "Edícia pre výuku",
     "Enterprise bundle" : "Enterprise balíček",
     "Groupware bundle" : "Balíček groupware",
+    "Hub bundle" : "Sada pre centrum aktivity (hub)",
     "Social sharing bundle" : "Balíček sociálneho zdieľania",
     "PHP %s or higher is required." : "Požadovaná verzia PHP %s alebo vyššia.",
     "PHP with a version lower than %s is required." : "PHP je vyžadované vo vyššej verzii ako %s.",
     "%sbit or higher PHP required." : "%sbit alebo vyššie PHP je vyžadované.",
-    "Following databases are supported: %s" : "Podporované sú tieto databázy: %s",
+    "The following architectures are supported: %s" : "Podporované sú nasledujúce architektúry: %s",
+    "The following databases are supported: %s" : "Podporované sú nasledujúce databázy: %s",
     "The command line tool %s could not be found" : "Nástroj príkazového riadka %s nebol nájdený",
     "The library %s is not available." : "Knižnica %s je nedostupná.",
-    "Library %s with a version higher than %s is required - available version %s." : "Požadovaná je knižnica %s vo vyššej verzii ako %s - dostupná verzia %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Požadovaná je knižnica %s v nižšej verzii ako %s - dostupná verzia %s.",
-    "Following platforms are supported: %s" : "Podporované sú nasledovné systémy: %s",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Požadovaná je knižnica %1$s vo vyššej verzii ako %2$s - dostupná verzia %3$s.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Požadovaná je knižnica %1$s v nižšej verzii ako %2$s - dostupná verzia %3$s.",
+    "The following platforms are supported: %s" : "Podporované sú nasledujúce platformy: %s",
     "Server version %s or higher is required." : "Je vyžadovaná verzia servera %s alebo vyššia.",
     "Server version %s or lower is required." : "Je vyžadovaná verzia servera %s alebo nižšia.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený používateľ musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu",
+    "Logged in user must be an admin or sub admin" : "Prihlásený používateľ musí byť správcom alebo správcom pre čiastkovú oblasť.",
+    "Logged in user must be an admin" : "Prihlásený používateľ musí byť správca",
+    "Wiping of device %s has started" : "Začalo sa mazanie zariadenia %s",
+    "Wiping of device »%s« has started" : "Začalo sa mazanie zariadenia „%s“",
+    "»%s« started remote wipe" : "„%s“ začalo mazanie na diaľku",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Zariadenie alebo aplikácia „%s“ začal proces mazania na diaľku. Po dokončení procesu dostanete ďalší e-mail",
+    "Wiping of device %s has finished" : "Mazanie zariadenia %s bolo dokončené.",
+    "Wiping of device »%s« has finished" : "Mazanie zariadenia „%s“ bolo dokončené.",
+    "»%s« finished remote wipe" : "„%s“ dokončilo mazanie na diaľku ",
+    "Device or application »%s« has finished the remote wipe process." : "Zariadenie alebo aplikácia „%s“ dokončilo(a) proces mazania na diaľku.",
+    "Remote wipe started" : "Začalo mazanie na diaľku",
+    "A remote wipe was started on device %s" : "Na zariadeni %s začalo mazanie na diaľku",
+    "Remote wipe finished" : "Mazanie na diaľku bolo dokončené",
+    "The remote wipe on %s has finished" : "Mazanie na diaľku na %s bolo dokončené",
+    "Authentication" : "Autentifikácia",
     "Unknown filetype" : "Neznámy typ súboru",
     "Invalid image" : "Chybný obrázok",
     "Avatar image is not square" : "Obrázok avatara nie je štvorcový",
+    "View profile" : "Zobraziť profil",
     "today" : "dnes",
     "tomorrow" : "zajtra",
     "yesterday" : "včera",
-    "_in %n day_::_in %n days_" : ["o %n deň","o %n dni","o %n dní"],
-    "_%n day ago_::_%n days ago_" : ["včera","pred %n dňami","pred %n dňami"],
+    "_in %n day_::_in %n days_" : ["o %n deň","o %n dni","o %n dní","o %n dní"],
+    "_%n day ago_::_%n days ago_" : ["včera","pred %n dňami","pred %n dňami","pred %n dňami"],
     "next month" : "budúci mesiac",
     "last month" : "minulý mesiac",
-    "_in %n month_::_in %n months_" : ["o %n mesiac ","o %n mesiace","o %n mesiacov"],
-    "_%n month ago_::_%n months ago_" : ["pred %n mesiacom","pred %n mesiacmi","pred %n mesiacmi"],
+    "_in %n month_::_in %n months_" : ["o %n mesiac ","o %n mesiace","o %n mesiacov","o %n mesiacov"],
+    "_%n month ago_::_%n months ago_" : ["pred %n mesiacom","pred %n mesiacmi","pred %n mesiacmi","pred %n mesiacmi"],
     "next year" : "budúci rok",
     "last year" : "minulý rok",
-    "_in %n year_::_in %n years_" : ["o %n rok","o %n roky","o %n rokov"],
-    "_%n year ago_::_%n years ago_" : ["vlani","pred %n rokmi","pred %n rokmi"],
-    "_in %n hour_::_in %n hours_" : ["o %n hodinu","o %n hodiny","o %n hodín"],
-    "_%n hour ago_::_%n hours ago_" : ["pred %n hodinou","pred %n hodinami","pred %n hodinami"],
-    "_in %n minute_::_in %n minutes_" : ["o %n minútu","o %n minúty","o %n minút"],
-    "_%n minute ago_::_%n minutes ago_" : ["pred %n minútou","pred %n minútami","pred %n minútami"],
+    "_in %n year_::_in %n years_" : ["o %n rok","o %n roky","o %n rokov","o %n rokov"],
+    "_%n year ago_::_%n years ago_" : ["vlani","pred %n rokmi","pred %n rokmi","pred %n rokmi"],
+    "_in %n hour_::_in %n hours_" : ["o %n hodinu","o %n hodiny","o %n hodín","o %n hodín"],
+    "_%n hour ago_::_%n hours ago_" : ["pred %n hodinou","pred %n hodinami","pred %n hodinami","pred %n hodinami"],
+    "_in %n minute_::_in %n minutes_" : ["o %n minútu","o %n minúty","o %n minút","o %n minút"],
+    "_%n minute ago_::_%n minutes ago_" : ["pred %n minútou","pred %n minútami","pred %n minútami","pred %n minútami"],
     "in a few seconds" : "o pár sekúnd",
     "seconds ago" : "pred sekundami",
+    "Empty file" : "Prázdny súbor",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s ID: %s neexistuje. Povoľte ho prosím vo vašom nastavení aplikácií alebo kontaktujte správcu.",
+    "File already exists" : "Súbor už existuje",
+    "Invalid path" : "Neplatná cesta",
+    "Failed to create file from template" : "Nemôžem vytvoriť súbor zo šablóny",
+    "Templates" : "Šablóny",
     "File name is a reserved word" : "Názov súboru je rezervované slovo.",
     "File name contains at least one invalid character" : "Názov súboru obsahuje nepovolené znaky.",
     "File name is too long" : "Meno súboru je veľmi dlhé.",
@@ -57,78 +87,65 @@ OC.L10N.register(
     "Empty filename is not allowed" : "Prázdny názov súboru nie je povolený",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikáciu \"%s\" nie je možné nainštalovať, lebo nebolo možné načítať súbor s informáciami o aplikácií.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikácia \"%s\" nie je kompatibilná s verziou servera, preto nemôže byť nainštalovaná.",
+    "__language_name__" : "Slovenčina",
     "This is an automatically sent email, please do not reply." : "Toto je automaticky odosielaný e-mail, prosím, neodpovedajte.",
     "Help" : "Pomoc",
     "Apps" : "Aplikácie",
     "Settings" : "Nastavenia",
     "Log out" : "Odhlásiť sa",
     "Users" : "Používatelia",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Basic settings" : "Základné nastavenia",
-    "Sharing" : "Sprístupnenie",
-    "Security" : "Zabezpečenie",
-    "Encryption" : "Šifrovanie",
+    "Email" : "E-mail",
+    "Mail %s" : "Pošta pre %s",
+    "Phone" : "Telefón",
+    "Call %s" : "Zavolať %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "Zobraziť %s na Twitteri",
+    "Website" : "Webstránka",
+    "Visit %s" : "Navštíviť %s",
+    "Address" : "Adresa",
+    "Profile picture" : "Profilový obrázok",
+    "About" : "O aplikácii",
+    "Full name" : "Celé meno",
+    "Headline" : "Titulok",
+    "Organisation" : "Organizácia",
+    "Role" : "Rola",
+    "Unknown user" : "Neznámy používateľ",
     "Additional settings" : "Ďalšie nastavenia",
-    "Tips & tricks" : "Tipy a triky",
-    "Personal info" : "Osobné informácie",
-    "Sync clients" : "Klienti synchronizácie",
-    "Unlimited" : "Neobmedzené",
-    "__language_name__" : "Slovenčina",
-    "Verifying" : "Overovanie",
-    "Verifying …" : "Overovanie ...",
-    "Verify" : "Overiť",
     "%s enter the database username and name." : "%s zadajte používateľské meno a meno databázy",
     "%s enter the database username." : "Zadajte používateľské meno %s databázy.",
     "%s enter the database name." : "Zadajte názov databázy pre %s databázy.",
     "%s you may not use dots in the database name" : "V názve databázy %s nemôžete používať bodky",
+    "MySQL username and/or password not valid" : "Neplatné užívateľské meno a/alebo heslo do MySQL",
+    "You need to enter details of an existing account." : "Musíte zadať údaje existujúceho účtu.",
     "Oracle connection could not be established" : "Nie je možné pripojiť sa k Oracle",
     "Oracle username and/or password not valid" : "Používateľské meno a/alebo heslo pre Oracle databázu je neplatné",
     "PostgreSQL username and/or password not valid" : "Používateľské meno a/alebo heslo pre PostgreSQL databázu je neplatné",
-    "You need to enter details of an existing account." : "Musíte zadať údaje existujúceho účtu.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použite ho na vlastné riziko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
     "Set an admin username." : "Zadajte používateľské meno administrátora.",
     "Set an admin password." : "Zadajte heslo administrátora.",
-    "Can't create or write into the data directory %s" : "Nemožno vytvoriť alebo zapisovať do priečinka dát %s",
-    "Invalid Federated Cloud ID" : "Neplatné združené Cloud ID",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Sprístupnenie %s zlyhalo, backend nepodporuje typ sprístupnenia %i",
-    "Sharing %s failed, because the file does not exist" : "Nie je možné sprístupniť %s, súbor neexistuje",
-    "You are not allowed to share %s" : "Nemôžete sprístupniť %s",
-    "Sharing %s failed, because you can not share with yourself" : "Sprístupnenie %s zlyhalo, nieje možné sprístupniť obsah so sebou samým",
-    "Sharing %s failed, because the user %s does not exist" : "Sprístupnenie %s zlyhalo, používateľ %s neexistuje",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Sprístupnenie %s zlyhalo, používateľ %s nie je členom žiadnej skupiny spoločnej s používateľom %s",
-    "Sharing %s failed, because this item is already shared with %s" : "Sprístupnenie %s zlyhalo, pretože táto položka už je prístupná pre %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sprístupnenie %s zlyhalo, táto položka už je používateľovi %s prístupná",
-    "Sharing %s failed, because the group %s does not exist" : "Sprístupnenie %s zlyhalo, skupina %s neexistuje",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Sprístupnenie %s zlyhalo, %s nie je členom skupiny %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Musíte zadať heslo ak chcete vytvoriť verejný odkaz, lebo iba odkazy chránené heslom sú povolené",
-    "Sharing %s failed, because sharing with links is not allowed" : "%s nie je možné sprístupniť, sprístupnenie prostredníctvom odkazu nie je povolené",
-    "Not allowed to create a federated share with the same user" : "Nie je možné vytvoriť združené sprístupnenie so sebou samým",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Sprístupňovanie %s zlyhalo, nepodarilo sa nájsť %s, možno je server dočasne nedostupný.",
-    "Share type %s is not valid for %s" : "Typ sprístupnenia %s nie je možný pre %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Sprístupnenie nemôže byť ukončené skôr, ako po %s dňoch.",
-    "Cannot set expiration date. Expiration date is in the past" : "Nie je možné nastaviť dátum konca platnosti. Dátum konca platnosti je v minulosti.",
+    "Cannot create or write into the data directory %s" : "Nemožno vytvoriť alebo zapisovať do priečinka dát %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend pre sprístupnenie %s musí implementovať rozhranie OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend sprístupnenia %s nebol nájdený",
     "Sharing backend for %s not found" : "Backend sprístupnenia pre %s nebol nájdený",
-    "Sharing failed, because the user %s is the original sharer" : "Sprístupnenie zlyhalo, pretože používateľ %s je pôvodný spoločný používateľ",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Sprístupnenie %s zlyhalo, pretože povolenia prekračujú povolenia udelené %s",
-    "Sharing %s failed, because resharing is not allowed" : "Nie je možné sprístupniť %s ďalším osobám",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Sprístupnenie %s zlyhalo, backend nenašiel zdrojový %s",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Sprístupnenie %s zlyhalo, pretože súbor sa nenachádza vo vyrovnávacej pamäti súborov",
-    "Can’t increase permissions of %s" : "Nie je možné navýšiť oprávnenia pre %s",
-    "Files can’t be shared with delete permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na odstránenie",
-    "Files can’t be shared with create permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na vytváranie",
-    "Expiration date is in the past" : "Dátum konca platnosti je v minulosti",
-    "Can’t set expiration date more than %s days in the future" : "Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti",
-    "%s shared »%s« with you" : "%s vám sprístupnil »%s«",
-    "%s shared »%s« with you." : "%s vám sprístupnil »%s«",
-    "Click the button below to open it." : "Pre otvorenie klienta kliknite na tlačítko nižšie.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vám sprístupnil »%2$s« s poznámkou:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s vám sprístupnil »%2$s« s poznámkou",
+    "»%s« added a note to a file shared with you" : "»%s« pridal poznámku k súboru ktorý s Vami zdieľa",
     "Open »%s«" : "Otvoriť »%s«",
-    "%s via %s" : "%s cez %s",
+    "%1$s via %2$s" : "%1$s cez %2$s",
+    "You are not allowed to share %s" : "Nemôžete sprístupniť %s",
+    "Cannot increase permissions of %s" : "Nie je možné navýšiť oprávnenia pre %s",
+    "Files cannot be shared with delete permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na odstránenie",
+    "Files cannot be shared with create permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na vytváranie",
+    "Expiration date is in the past" : "Dátum konca platnosti je v minulosti",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nie je možné nastaviť dátum konca platnosti viac ako %s deň v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti"],
+    "Sharing is only allowed with group members" : "Zdieľanie je možné iba s členmi skupiny",
+    "Sharing %s failed, because this item is already shared with user %s" : "Sprístupnenie %s zlyhalo, táto položka už je používateľovi %s zozdieľaná",
+    "%1$s shared »%2$s« with you" : "%1$s vám sprístupnil »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s vám sprístupnil »%2$s«.",
+    "Click the button below to open it." : "Pre otvorenie klienta kliknite na tlačítko nižšie.",
     "The requested share does not exist anymore" : "Požadované sprístupnenie už neexistuje",
     "Could not find category \"%s\"" : "Nemožno nájsť danú kategóriu \"%s\"",
     "Sunday" : "Nedeľa",
@@ -176,83 +193,86 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
+    "The user limit has been reached and the user was not created." : "Bol dosiahnutý limit používateľov a používateľ nebol vytvorený.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "V mene používateľa je možné použiť iba nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
     "A valid username must be provided" : "Musíte zadať platné používateľské meno",
     "Username contains whitespace at the beginning or at the end" : "Meno používateľa obsahuje na začiatku, alebo na konci medzeru",
     "Username must not consist of dots only" : "Používateľské meno sa nesmie skladať len z bodiek",
+    "Username is invalid because files already exist for this user" : "Používateľské meno je neplatné, pretože pre tohto používateľa už existujú súbory",
     "A valid password must be provided" : "Musíte zadať platné heslo",
     "The username is already being used" : "Meno používateľa je už použité",
     "Could not create user" : "Nepodarilo sa vytvoriť používateľa",
     "User disabled" : "Používateľ zakázaný",
     "Login canceled by app" : "Prihlásenie bolo zrušené aplikáciou",
-    "No app name specified" : "Nešpecifikované meno aplikácie",
-    "App '%s' could not be installed!" : "Aplikáciu '%s' nebolo možné nainštalovať!",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikáciu \"%s\" nie je možné inštalovať, pretože nie sú splnené nasledovné závislosti: %s",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikáciu \"%1$s\" nie je možné inštalovať, pretože nie sú splnené nasledovné závislosti: %2$s",
     "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
     "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
-    "Can't read file" : "Nemožno čítať súbor.",
     "Application is not enabled" : "Aplikácia nie je zapnutá",
     "Authentication error" : "Chyba autentifikácie",
     "Token expired. Please reload page." : "Token vypršal. Obnovte, prosím, stránku.",
-    "Unknown user" : "Neznámy používateľ",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ovládače databázy (sqlite, mysql, alebo postgresql) nie sú nainštalované.",
-    "Cannot write into \"config\" directory" : "Nie je možné zapisovať do priečinka \"config\"",
-    "Cannot write into \"apps\" directory" : "Nie je možné zapisovať do priečinka \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Toto je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do priečinka aplikácií alebo vypnete obchod s aplikáciami v konfiguračnom súbore. Viď %s",
-    "Cannot create \"data\" directory" : "Nie je možné vytvoriť priečinok \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového adresára. Viď %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Oprávnenia je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového priečinka. Viď %s.",
-    "Setting locale to %s failed" : "Nastavenie locale na %s zlyhalo",
-    "Please install one of these locales on your system and restart your webserver." : "Prosím, nainštalujte si aspoň jeden z týchto jazykov so svojho systému a reštartujte webserver.",
-    "Please ask your server administrator to install the module." : "Prosím, požiadajte administrátora vášho servera o inštaláciu modulu.",
+    "Cannot write into \"config\" directory." : "Nie je možné zapisovať do priečinka \"config\".",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do adresára s konfiguráciou. Viď %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Alebo, ak preferujete ponechať súbor config.php iba na čítanie, nastavte v ňom parameter \"config_is_read_only\" na true.  Viď %s",
+    "Cannot write into \"apps\" directory." : "Nie je možné zapisovať do priečinka \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami.",
+    "Cannot create \"data\" directory." : "Nie je možné vytvoriť priečinok \"data\"",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového adresára. Viď %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Oprávnenia je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového priečinka. Viď %s.",
+    "Your data directory is not writable." : "Priečinok s dátami nie je zapisovateľný.",
+    "Setting locale to %s failed." : "Nastavenie locale na %s zlyhalo.",
+    "Please install one of these locales on your system and restart your web server." : "Prosím, nainštalujte si aspoň jeden z týchto jazykov do svojho systému a reštartujte webserver.",
     "PHP module %s not installed." : "PHP modul %s nie je nainštalovaný.",
+    "Please ask your server administrator to install the module." : "Prosím, požiadajte administrátora vášho servera o inštaláciu modulu.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Voľba PHP „%s“ nie je nastavená na „%s“.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Použitím týchto nastavení v php.ini dovolí Nextcloudu sa znova spustiť",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastavený na \"%s\", namiesto predpokladanej hodnoty \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastavený na <code>%s</code>, namiesto predpokladanej hodnoty <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini.",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vyžadovaná verzia libxml2 je 2.7.0 a vyššia. Momentálne je nainštalovaná verzia %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Pre vyriešenie tohto problému aktualizujte prosím verziu libxml2 a reštartujte webový server.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je zjavne nastavené, aby odstraňovalo bloky vloženej dokumentácie. To zneprístupní niekoľko základných aplikácií.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "To je pravdepodobne spôsobené cache/akcelerátorom ako napr. Zend OPcache alebo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly boli nainštalované, ale stále sa tvária, že chýbajú?",
     "Please ask your server administrator to restart the web server." : "Prosím, požiadajte administrátora vášho servera o reštartovanie webového servera.",
-    "PostgreSQL >= 9 required" : "Vyžadované PostgreSQL >= 9",
-    "Please upgrade your database version" : "Prosím, aktualizujte verziu svojej databázy",
+    "The required %s config variable is not configured in the config.php file." : "Požadovaná konfiguračná premenná %s nie je nakonfigurovaná v súbore config.php.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Požiadajte správcu servera, aby skontroloval konfiguráciu Nextcloud.",
+    "PostgreSQL >= 9 required." : "Vyžadované PostgreSQL >= 9.",
+    "Please upgrade your database version." : "Prosím, aktualizujte verziu svojej databázy.",
+    "Your data directory is readable by other users." : "Váš priečinok s dátami je prístupný na čítanie ostatným užívateľom.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť.",
-    "Your data directory is readable by other users" : "Váš priečinok s dátami je prístupný na čítanie ostatným používateľom",
-    "Your data directory must be an absolute path" : "Priečinok s dátami musí byť zadaný ako absolútna cesta",
-    "Check the value of \"datadirectory\" in your configuration" : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii",
-    "Your data directory is invalid" : "Priečinok s dátami je neplatný",
+    "Your data directory must be an absolute path." : "Priečinok s dátami musí byť zadaný ako absolútna cesta.",
+    "Check the value of \"datadirectory\" in your configuration." : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii.",
+    "Your data directory is invalid." : "Priečinok pre dáta je neplatný.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Uistite sa, že v koreňovom adresári sa nachádza súbor s názvom \".ocdata\".",
+    "Action \"%s\" not supported or implemented." : "Akcia \"%s\" nie je podporovaná alebo implementovaná.",
+    "Authentication failed, wrong token or provider ID given" : "Autentifikácia zlyhala, bol zadaný neplatný token alebo ID poskytovateľa",
+    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Pre dokončenie požiadavky chýbajú parametre.  Chýbajúce parametre: \"%s\"",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" je už použité v združenom cloude \"%2$s\"",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Poskytovateľ združeného cloudu s ID: \"%s\" neexistuje.",
     "Could not obtain lock type %d on \"%s\"." : "Nepodarilo sa získať zámok typu %d na „%s“.",
     "Storage unauthorized. %s" : "Úložisko neoverené. %s",
     "Storage incomplete configuration. %s" : "Neplatná konfigurácia úložiska. %s",
     "Storage connection error. %s" : "Chyba pripojenia k úložisku. %s",
     "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
     "Storage connection timeout. %s" : "Vypršanie pripojenia k úložisku. %s",
-    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "To je zvyčajne možné opraviť tým, že %s udelíte webovému serveru oprávnenie na zápis k adresáru s konfiguráciou%s.",
-    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s ID: %s neexistuje. Povoľte ho prosím vo vašom nastavení aplikácií alebo konaktujte správcu.",
-    "Server settings" : "Nastavenia servera",
-    "DB Error: \"%s\"" : "Chyba DB: \"%s\"",
-    "Offending command was: \"%s\"" : "Podozrivý príkaz bol: \"%s\"",
-    "You need to enter either an existing account or the administrator." : "Musíte zadať jestvujúci účet alebo administrátora.",
-    "Offending command was: \"%s\", name: %s, password: %s" : "Podozrivý príkaz bol: \"%s\", meno: %s, heslo: %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nastavenie povolení pre %s zlyhalo, pretože povolenia prekračujú povolenia udelené %s",
-    "Setting permissions for %s failed, because the item was not found" : "Nastavenie povolení pre %s zlyhalo, pretože položka sa nenašla",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "Nemožno vymazať čas expirácie. Pri sprístupnení je čas exspirácie vyžadovaný.",
-    "Cannot increase permissions of %s" : "Nie je možné navýšiť oprávnenia pre %s",
-    "Files can't be shared with delete permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na odstránenie",
-    "Files can't be shared with create permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na vytváranie",
-    "Cannot set expiration date more than %s days in the future" : "Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti",
-    "Personal" : "Osobné",
-    "Admin" : "Administrátor",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Toto je zvyčajne možné opraviť tým, že %s udelíte webovému serveru oprávnenie na zápis do priečinka aplikácií %s alebo vypnete obchod s aplikáciami v konfiguračnom súbore.",
-    "Cannot create \"data\" directory (%s)" : "Nie je možné vytvoriť priečinok \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "To je zvyčajne možné opraviť tým <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">že udelíte webovému serveru oprávnenie na zápis do koreňového priečinka</a>.",
-    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Oprávnenia je zvyčajne možné opraviť tým, že %sudelíte webovému serveru oprávnenie na zápis do koreňového priečinka%s.",
-    "Data directory (%s) is readable by other users" : "Priečinok dát (%s) je prístupný na čítanie ostatným používateľom",
-    "Data directory (%s) must be an absolute path" : "Priečinok dát (%s) musí byť zadaný ako absolútna cesta",
-    "Data directory (%s) is invalid" : "Priečinok dát (%s) je neplatný",
-    "Please check that the data directory contains a file \".ocdata\" in its root." : "Prosím, skontrolujte, či priečinok dát obsahuje súbor \".ocdata\"."
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s nastaveniami.",
+    "Cannot read file" : "Nemožno čítať súbor.",
+    "Cannot write into \"config\" directory" : "Nie je možné zapisovať do priečinka \"config\"",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do adresára s konfiguráciou. Viď %s",
+    "Cannot write into \"apps\" directory" : "Nie je možné zapisovať do priečinka \"apps\"",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami.",
+    "Cannot create \"data\" directory" : "Nie je možné vytvoriť priečinok \"data\"",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového adresára. Viď %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Oprávnenia je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového priečinka. Viď %s.",
+    "Setting locale to %s failed" : "Nastavenie locale na %s zlyhalo",
+    "Please install one of these locales on your system and restart your webserver." : "Prosím, nainštalujte si aspoň jeden z týchto jazykov so svojho systému a reštartujte webserver.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastavený na \"%s\", namiesto predpokladanej hodnoty \"0\"",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini",
+    "PostgreSQL >= 9 required" : "Vyžadované PostgreSQL >= 9",
+    "Please upgrade your database version" : "Prosím, aktualizujte verziu svojej databázy",
+    "Your data directory is readable by other users" : "Váš priečinok s dátami je prístupný na čítanie ostatným používateľom",
+    "Your data directory must be an absolute path" : "Priečinok s dátami musí byť zadaný ako absolútna cesta",
+    "Check the value of \"datadirectory\" in your configuration" : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii",
+    "Your data directory is invalid" : "Priečinok s dátami je neplatný"
 },
-"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
+"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
