@@ -12,6 +12,7 @@
  * @author Frédéric Fortier <frederic.fortier@oronospolytechnique.com>
  * @author Jens-Christian Fischer <jens-christian.fischer@switch.ch>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author John Molakvoæ <skjnldsv@protonmail.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
@@ -40,7 +41,8 @@
 namespace OC\Files\Cache;
 
 use Doctrine\DBAL\Exception\UniqueConstraintViolationException;
-use OCP\DB\IResult;
+use OC\Files\Search\SearchComparison;
+use OC\Files\Search\SearchQuery;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Files\Cache\CacheEntryInsertedEvent;
@@ -52,9 +54,12 @@ use OCP\Files\Cache\ICache;
 use OCP\Files\Cache\ICacheEntry;
 use OCP\Files\FileInfo;
 use OCP\Files\IMimeTypeLoader;
+use OCP\Files\Search\ISearchComparison;
+use OCP\Files\Search\ISearchOperator;
 use OCP\Files\Search\ISearchQuery;
 use OCP\Files\Storage\IStorage;
 use OCP\IDBConnection;
+use Psr\Log\LoggerInterface;
 
 /**
  * Metadata cache for a storage
@@ -62,8 +67,8 @@ use OCP\IDBConnection;
  * The cache stores the metadata for all files and folders in a storage and is kept up to date trough the following mechanisms:
  *
  * - Scanner: scans the storage and updates the cache where needed
- * - Watcher: checks for changes made to the filesystem outside of the ownCloud instance and rescans files and folder when a change is detected
- * - Updater: listens to changes made to the filesystem inside of the ownCloud instance and updates the cache where needed
+ * - Watcher: checks for changes made to the filesystem outside of the Nextcloud instance and rescans files and folder when a change is detected
+ * - Updater: listens to changes made to the filesystem inside of the Nextcloud instance and updates the cache where needed
  * - ChangePropagator: updates the mtime and etags of parent folders whenever a change to the cache is made to the cache by the updater
  */
 class Cache implements ICache {
@@ -118,15 +123,14 @@ class Cache implements ICache {
 		$this->mimetypeLoader = \OC::$server->getMimeTypeLoader();
 		$this->connection = \OC::$server->getDatabaseConnection();
 		$this->eventDispatcher = \OC::$server->get(IEventDispatcher::class);
-		$this->querySearchHelper = new QuerySearchHelper($this->mimetypeLoader);
+		$this->querySearchHelper = \OC::$server->query(QuerySearchHelper::class);
 	}
 
-	private function getQueryBuilder() {
+	protected function getQueryBuilder() {
 		return new CacheQueryBuilder(
 			$this->connection,
 			\OC::$server->getSystemConfig(),
-			\OC::$server->getLogger(),
-			$this
+			\OC::$server->get(LoggerInterface::class)
 		);
 	}
 
@@ -149,11 +153,11 @@ class Cache implements ICache {
 		$query = $this->getQueryBuilder();
 		$query->selectFileCache();
 
-		if (is_string($file) or $file == '') {
+		if (is_string($file) || $file == '') {
 			// normalize file
 			$file = $this->normalize($file);
 
-			$query->whereStorageId()
+			$query->whereStorageId($this->getNumericStorageId())
 				->wherePath($file);
 		} else { //file id
 			$query->whereFileId($file);
@@ -164,7 +168,7 @@ class Cache implements ICache {
 		$result->closeCursor();
 
 		//merge partial data
-		if (!$data and is_string($file) and isset($this->partial[$file])) {
+		if (!$data && is_string($file) && isset($this->partial[$file])) {
 			return $this->partial[$file];
 		} elseif (!$data) {
 			return $data;
@@ -185,6 +189,7 @@ class Cache implements ICache {
 		$data['fileid'] = (int)$data['fileid'];
 		$data['parent'] = (int)$data['parent'];
 		$data['size'] = 0 + $data['size'];
+		$data['unencrypted_size'] = 0 + ($data['unencrypted_size'] ?? 0);
 		$data['mtime'] = (int)$data['mtime'];
 		$data['storage_mtime'] = (int)$data['storage_mtime'];
 		$data['encryptedVersion'] = (int)$data['encrypted'];
@@ -198,10 +203,10 @@ class Cache implements ICache {
 		}
 		$data['permissions'] = (int)$data['permissions'];
 		if (isset($data['creation_time'])) {
-			$data['creation_time'] = (int) $data['creation_time'];
+			$data['creation_time'] = (int)$data['creation_time'];
 		}
 		if (isset($data['upload_time'])) {
-			$data['upload_time'] = (int) $data['upload_time'];
+			$data['upload_time'] = (int)$data['upload_time'];
 		}
 		return new CacheEntry($data);
 	}
@@ -425,7 +430,7 @@ class Cache implements ICache {
 	protected function normalizeData(array $data): array {
 		$fields = [
 			'path', 'parent', 'name', 'mimetype', 'size', 'mtime', 'storage_mtime', 'encrypted',
-			'etag', 'permissions', 'checksum', 'storage'];
+			'etag', 'permissions', 'checksum', 'storage', 'unencrypted_size'];
 		$extensionFields = ['metadata_etag', 'creation_time', 'upload_time'];
 
 		$doNotCopyStorageMTime = false;
@@ -482,7 +487,7 @@ class Cache implements ICache {
 		$query = $this->getQueryBuilder();
 		$query->select('fileid')
 			->from('filecache')
-			->whereStorageId()
+			->whereStorageId($this->getNumericStorageId())
 			->wherePath($file);
 
 		$result = $query->execute();
@@ -535,7 +540,7 @@ class Cache implements ICache {
 	public function remove($file) {
 		$entry = $this->get($file);
 
-		if ($entry) {
+		if ($entry instanceof ICacheEntry) {
 			$query = $this->getQueryBuilder();
 			$query->delete('filecache')
 				->whereFileId($entry->getId());
@@ -587,8 +592,12 @@ class Cache implements ICache {
 
 			$query = $this->getQueryBuilder();
 			$query->delete('filecache_extended')
-				->where($query->expr()->in('fileid', $query->createNamedParameter($childIds, IQueryBuilder::PARAM_INT_ARRAY)));
-			$query->execute();
+				->where($query->expr()->in('fileid', $query->createParameter('childIds')));
+
+			foreach (array_chunk($childIds, 1000) as $childIdChunk) {
+				$query->setParameter('childIds', $childIdChunk, IQueryBuilder::PARAM_INT_ARRAY);
+				$query->execute();
+			}
 
 			/** @var ICacheEntry[] $childFolders */
 			$childFolders = array_filter($children, function ($child) {
@@ -602,8 +611,12 @@ class Cache implements ICache {
 
 		$query = $this->getQueryBuilder();
 		$query->delete('filecache')
-			->whereParentIn($parentIds);
-		$query->execute();
+			->whereParentInParameter('parentIds');
+
+		foreach (array_chunk($parentIds, 1000) as $parentIdChunk) {
+			$query->setParameter('parentIds', $parentIdChunk, IQueryBuilder::PARAM_INT_ARRAY);
+			$query->execute();
+		}
 	}
 
 	/**
@@ -629,7 +642,7 @@ class Cache implements ICache {
 	/**
 	 * Move a file or folder in the cache
 	 *
-	 * @param \OCP\Files\Cache\ICache $sourceCache
+	 * @param ICache $sourceCache
 	 * @param string $sourcePath
 	 * @param string $targetPath
 	 * @throws \OC\DatabaseException
@@ -642,6 +655,10 @@ class Cache implements ICache {
 			$targetPath = $this->normalize($targetPath);
 
 			$sourceData = $sourceCache->get($sourcePath);
+			if ($sourceData === false) {
+				throw new \Exception('Invalid source storage path: ' . $sourcePath);
+			}
+
 			$sourceId = $sourceData['fileid'];
 			$newParentId = $this->getParentId($targetPath);
 
@@ -714,7 +731,7 @@ class Cache implements ICache {
 	public function clear() {
 		$query = $this->getQueryBuilder();
 		$query->delete('filecache')
-			->whereStorageId();
+			->whereStorageId($this->getNumericStorageId());
 		$query->execute();
 
 		$query = $this->connection->getQueryBuilder();
@@ -742,7 +759,7 @@ class Cache implements ICache {
 		$query = $this->getQueryBuilder();
 		$query->select('size')
 			->from('filecache')
-			->whereStorageId()
+			->whereStorageId($this->getNumericStorageId())
 			->wherePath($file);
 
 		$result = $query->execute();
@@ -771,37 +788,8 @@ class Cache implements ICache {
 	 * @return ICacheEntry[] an array of cache entries where the name matches the search pattern
 	 */
 	public function search($pattern) {
-		// normalize pattern
-		$pattern = $this->normalize($pattern);
-
-		if ($pattern === '%%') {
-			return [];
-		}
-
-		$query = $this->getQueryBuilder();
-		$query->selectFileCache()
-			->whereStorageId()
-			->andWhere($query->expr()->iLike('name', $query->createNamedParameter($pattern)));
-
-		$result = $query->execute();
-		$files = $result->fetchAll();
-		$result->closeCursor();
-
-		return array_map(function (array $data) {
-			return self::cacheEntryFromData($data, $this->mimetypeLoader);
-		}, $files);
-	}
-
-	/**
-	 * @param IResult $result
-	 * @return CacheEntry[]
-	 */
-	private function searchResultToCacheEntries(IResult $result): array {
-		$files = $result->fetchAll();
-
-		return array_map(function (array $data) {
-			return self::cacheEntryFromData($data, $this->mimetypeLoader);
-		}, $files);
+		$operator = new SearchComparison(ISearchComparison::COMPARE_LIKE, 'name', $pattern);
+		return $this->searchQuery(new SearchQuery($operator, 0, 0, [], null));
 	}
 
 	/**
@@ -812,67 +800,16 @@ class Cache implements ICache {
 	 * @return ICacheEntry[] an array of cache entries where the mimetype matches the search
 	 */
 	public function searchByMime($mimetype) {
-		$mimeId = $this->mimetypeLoader->getId($mimetype);
-
-		$query = $this->getQueryBuilder();
-		$query->selectFileCache()
-			->whereStorageId();
-
-		if (strpos($mimetype, '/')) {
-			$query->andWhere($query->expr()->eq('mimetype', $query->createNamedParameter($mimeId, IQueryBuilder::PARAM_INT)));
+		if (strpos($mimetype, '/') === false) {
+			$operator = new SearchComparison(ISearchComparison::COMPARE_LIKE, 'mimetype', $mimetype . '/%');
 		} else {
-			$query->andWhere($query->expr()->eq('mimepart', $query->createNamedParameter($mimeId, IQueryBuilder::PARAM_INT)));
+			$operator = new SearchComparison(ISearchComparison::COMPARE_EQUAL, 'mimetype', $mimetype);
 		}
-
-		$result = $query->execute();
-		$files = $result->fetchAll();
-		$result->closeCursor();
-
-		return array_map(function (array $data) {
-			return self::cacheEntryFromData($data, $this->mimetypeLoader);
-		}, $files);
+		return $this->searchQuery(new SearchQuery($operator, 0, 0, [], null));
 	}
 
 	public function searchQuery(ISearchQuery $searchQuery) {
-		$builder = $this->getQueryBuilder();
-
-		$query = $builder->selectFileCache('file');
-
-		$query->whereStorageId();
-
-		if ($this->querySearchHelper->shouldJoinTags($searchQuery->getSearchOperation())) {
-			$query
-				->innerJoin('file', 'vcategory_to_object', 'tagmap', $builder->expr()->eq('file.fileid', 'tagmap.objid'))
-				->innerJoin('tagmap', 'vcategory', 'tag', $builder->expr()->andX(
-					$builder->expr()->eq('tagmap.type', 'tag.type'),
-					$builder->expr()->eq('tagmap.categoryid', 'tag.id')
-				))
-				->andWhere($builder->expr()->eq('tag.type', $builder->createNamedParameter('files')))
-				->andWhere($builder->expr()->eq('tag.uid', $builder->createNamedParameter($searchQuery->getUser()->getUID())));
-		}
-
-		$searchExpr = $this->querySearchHelper->searchOperatorToDBExpr($builder, $searchQuery->getSearchOperation());
-		if ($searchExpr) {
-			$query->andWhere($searchExpr);
-		}
-
-		if ($searchQuery->limitToHome() && ($this instanceof HomeCache)) {
-			$query->andWhere($builder->expr()->like('path', $query->expr()->literal('files/%')));
-		}
-
-		$this->querySearchHelper->addSearchOrdersToQuery($query, $searchQuery->getOrder());
-
-		if ($searchQuery->getLimit()) {
-			$query->setMaxResults($searchQuery->getLimit());
-		}
-		if ($searchQuery->getOffset()) {
-			$query->setFirstResult($searchQuery->getOffset());
-		}
-
-		$result = $query->execute();
-		$cacheEntries = $this->searchResultToCacheEntries($result);
-		$result->closeCursor();
-		return $cacheEntries;
+		return current($this->querySearchHelper->searchInCaches($searchQuery, [$this]));
 	}
 
 	/**
@@ -885,7 +822,7 @@ class Cache implements ICache {
 		$this->calculateFolderSize($path, $data);
 		if ($path !== '') {
 			$parent = dirname($path);
-			if ($parent === '.' or $parent === '/') {
+			if ($parent === '.' || $parent === '/') {
 				$parent = '';
 			}
 			if ($isBackgroundScan) {
@@ -931,25 +868,39 @@ class Cache implements ICache {
 	 */
 	public function calculateFolderSize($path, $entry = null) {
 		$totalSize = 0;
-		if (is_null($entry) or !isset($entry['fileid'])) {
+		if (is_null($entry) || !isset($entry['fileid'])) {
 			$entry = $this->get($path);
 		}
 		if (isset($entry['mimetype']) && $entry['mimetype'] === FileInfo::MIMETYPE_FOLDER) {
 			$id = $entry['fileid'];
 
 			$query = $this->getQueryBuilder();
-			$query->selectAlias($query->func()->sum('size'), 'f1')
-				->selectAlias($query->func()->min('size'), 'f2')
+			$query->select('size', 'unencrypted_size')
 				->from('filecache')
-				->whereStorageId()
 				->whereParent($id);
 
 			$result = $query->execute();
-			$row = $result->fetch();
+			$rows = $result->fetchAll();
 			$result->closeCursor();
 
-			if ($row) {
-				[$sum, $min] = array_values($row);
+			if ($rows) {
+				$sizes = array_map(function (array $row) {
+					return (int)$row['size'];
+				}, $rows);
+				$unencryptedOnlySizes = array_map(function (array $row) {
+					return (int)$row['unencrypted_size'];
+				}, $rows);
+				$unencryptedSizes = array_map(function (array $row) {
+					return (int)(($row['unencrypted_size'] > 0) ? $row['unencrypted_size']: $row['size']);
+				}, $rows);
+
+				$sum = array_sum($sizes);
+				$min = min($sizes);
+
+				$unencryptedSum = array_sum($unencryptedSizes);
+				$unencryptedMin = min($unencryptedSizes);
+				$unencryptedMax = max($unencryptedOnlySizes);
+
 				$sum = 0 + $sum;
 				$min = 0 + $min;
 				if ($min === -1) {
@@ -957,8 +908,23 @@ class Cache implements ICache {
 				} else {
 					$totalSize = $sum;
 				}
+				if ($unencryptedMin === -1 || $min === -1) {
+					$unencryptedTotal = $unencryptedMin;
+				} else {
+					$unencryptedTotal = $unencryptedSum;
+				}
 				if ($entry['size'] !== $totalSize) {
-					$this->update($id, ['size' => $totalSize]);
+					// only set unencrypted size for a folder if any child entries have it set
+					if ($unencryptedMax > 0) {
+						$this->update($id, [
+							'size' => $totalSize,
+							'unencrypted_size' => $unencryptedTotal,
+						]);
+					} else {
+						$this->update($id, [
+							'size' => $totalSize,
+						]);
+					}
 				}
 			}
 		}
@@ -974,7 +940,7 @@ class Cache implements ICache {
 		$query = $this->getQueryBuilder();
 		$query->select('fileid')
 			->from('filecache')
-			->whereStorageId();
+			->whereStorageId($this->getNumericStorageId());
 
 		$result = $query->execute();
 		$files = $result->fetchAll(\PDO::FETCH_COLUMN);
@@ -998,7 +964,7 @@ class Cache implements ICache {
 		$query = $this->getQueryBuilder();
 		$query->select('path')
 			->from('filecache')
-			->whereStorageId()
+			->whereStorageId($this->getNumericStorageId())
 			->andWhere($query->expr()->lt('size', $query->createNamedParameter(0, IQueryBuilder::PARAM_INT)))
 			->orderBy('fileid', 'DESC')
 			->setMaxResults(1);
@@ -1020,7 +986,7 @@ class Cache implements ICache {
 		$query = $this->getQueryBuilder();
 		$query->select('path')
 			->from('filecache')
-			->whereStorageId()
+			->whereStorageId($this->getNumericStorageId())
 			->whereFileId($id);
 
 		$result = $query->execute();
@@ -1031,7 +997,7 @@ class Cache implements ICache {
 			return null;
 		}
 
-		return (string) $path;
+		return (string)$path;
 	}
 
 	/**
@@ -1076,4 +1042,59 @@ class Cache implements ICache {
 	public function normalize($path) {
 		return trim(\OC_Util::normalizeUnicode($path), '/');
 	}
+
+	/**
+	 * Copy a file or folder in the cache
+	 *
+	 * @param ICache $sourceCache
+	 * @param ICacheEntry $sourceEntry
+	 * @param string $targetPath
+	 * @return int fileId of copied entry
+	 */
+	public function copyFromCache(ICache $sourceCache, ICacheEntry $sourceEntry, string $targetPath): int {
+		if ($sourceEntry->getId() < 0) {
+			throw new \RuntimeException("Invalid source cache entry on copyFromCache");
+		}
+		$data = $this->cacheEntryToArray($sourceEntry);
+		$fileId = $this->put($targetPath, $data);
+		if ($fileId <= 0) {
+			throw new \RuntimeException("Failed to copy to " . $targetPath . " from cache with source data " . json_encode($data) . " ");
+		}
+		if ($sourceEntry->getMimeType() === ICacheEntry::DIRECTORY_MIMETYPE) {
+			$folderContent = $sourceCache->getFolderContentsById($sourceEntry->getId());
+			foreach ($folderContent as $subEntry) {
+				$subTargetPath = $targetPath . '/' . $subEntry->getName();
+				$this->copyFromCache($sourceCache, $subEntry, $subTargetPath);
+			}
+		}
+		return $fileId;
+	}
+
+	private function cacheEntryToArray(ICacheEntry $entry): array {
+		return [
+			'size' => $entry->getSize(),
+			'mtime' => $entry->getMTime(),
+			'storage_mtime' => $entry->getStorageMTime(),
+			'mimetype' => $entry->getMimeType(),
+			'mimepart' => $entry->getMimePart(),
+			'etag' => $entry->getEtag(),
+			'permissions' => $entry->getPermissions(),
+			'encrypted' => $entry->isEncrypted(),
+			'creation_time' => $entry->getCreationTime(),
+			'upload_time' => $entry->getUploadTime(),
+			'metadata_etag' => $entry->getMetadataEtag(),
+		];
+	}
+
+	public function getQueryFilterForStorage(): ISearchOperator {
+		return new SearchComparison(ISearchComparison::COMPARE_EQUAL, 'storage', $this->getNumericStorageId());
+	}
+
+	public function getCacheEntryFromSearchResult(ICacheEntry $rawEntry): ?ICacheEntry {
+		if ($rawEntry->getStorageId() === $this->getNumericStorageId()) {
+			return $rawEntry;
+		} else {
+			return null;
+		}
+	}
 }
